## Replication Figure 1-3

# Load Packages
library(readr)
library(readxl)
library(dplyr)
library(ggplot2)
library(lmtest)
library(stargazer)
library(sandwich)
library(lubridate)
library(AER)
library(scales)
library(pscl)
library(plm)
library(urca)
library(tseries)
library(EventStudy)
library(gridExtra)
library(mfx)
library(stringr)
library(sf)
library(fixest)

# Set Working Directory to the 'Data' Folder of the Replication Package
setwd("XXX")

# Load Data
Spiele <- read_excel("Spiele.xlsx")
Spiele_2 <- Spiele
Stadien <- read_excel("Stadien.xlsx")
Map <- st_read("VG250_KRS.shp")
Panel <- read_csv("Panel.csv")
Panel <- Panel[,-1]

### Figure 1: Number Matches over Time
Date <- group_by(Spiele, Datum)
Date$Identifier <- "Ghost Game"
Date$Identifier[Date$Zuschauer>0] <- "Visitors"
Date$Spiel <- 1
Date$Datum <- as.Date(Date$Datum)
Date <- group_by(Date, Datum, Identifier)
Date <- summarize(Date, Matches=sum(Spiel))
ggplot(Date, aes(Datum, Matches, fill=Identifier)) + geom_bar(stat="identity", width=0.75) + labs(y="# Matches", x="Date") + theme_classic() + theme(legend.title = element_blank()) + theme(legend.position="bottom") + scale_fill_manual("legend", values = c("Ghost Game" = alpha("navyblue", .5), "Visitors" = alpha("navyblue", .2)))

### Figure 2: Left Plot
ggplot(Spiele[Spiele$Zuschauer>0,], aes(x=Zuschauer)) + geom_histogram(color="black", fill="navyblue", alpha=0.35, bins = 100) + labs(x="Attendance", y="# Matches") + theme_classic()

### Figure 2: Right Plot
Spiele <- left_join(Spiele, filter(Stadien, Saison=="2019/2020"), by = c("Stadion" = "Club"))
Spiele$Altitude <- NULL
Spiele$Track <- NULL
Spiele$Saison <- NULL
Spiele$Age <- NULL
Spiele$Longitude <- NULL
Spiele$Latitude <- NULL
Spiele$Heim <- NULL
Spiele$Auswaerts <- NULL
Spiele$Stadion <- NULL
Spiele$Datum <- as.Date(Spiele$Datum)
Spiele$Spiel <- 1
Spiele$Auslastung <- Spiele$Zuschauer/Spiele$Capacity
ggplot(Spiele[Spiele$Zuschauer>0,], aes(x=Auslastung)) + geom_histogram(color="black", fill="navyblue", alpha=0.35, bins=100) + labs(x="Occupancy", y="# Matches") + theme_classic()

### Figure 3: Maps
Map$ARS[Map$ARS=="11000"] <- "11"
Panel_Map <- Panel
Panel_Map$Spiel_pro_Einwohner <- Panel_Map$Spiel/Panel_Map$Einwohner*100000
Panel_Map$Spiel_pro_Einwohner[is.na(Panel_Map$Spiel_pro_Einwohner)] <- 0
Panel_Map <- summarize(group_by(Panel_Map, IdLandkreis), Matches_per_Einwohner=sum(Spiel_pro_Einwohner))
Map <- left_join(Map, Panel_Map, by = c("ARS" = "IdLandkreis"))
Panel_Map <- Panel
Panel_Map$Visitors_pro_Einwohner <- Panel_Map$Zuschauer/Panel_Map$Einwohner*100000
Panel_Map$Visitors_pro_Einwohner[is.na(Panel_Map$Visitors_pro_Einwohner)] <- 0
Panel_Map <- summarize(group_by(Panel_Map, IdLandkreis), Visitors_per_Einwohner=sum(Visitors_pro_Einwohner))
Map <- left_join(Map, Panel_Map, by = c("ARS" = "IdLandkreis"))
Panel_Map <- Panel[Panel$Meldedatum>="2020-08-10" & Panel$Meldedatum<="2020-11-08",]
Panel_Map <- summarize(group_by(Panel_Map, IdLandkreis), Incidence=sum(Faelle)/mean(Einwohner)*100000)
Map <- left_join(Map, Panel_Map, by = c("ARS" = "IdLandkreis"))
Spiele_2$count <- 1
Spiele_2$count2 <- ifelse(Spiele_2$Zuschauer>0, 1, 0)
map <- summarize(group_by(left_join(Spiele_2, filter(Stadien, Saison=="2019/2020"), by = c("Stadion" = "Club")), Heimkreis), share_visitors=sum(count2)/sum(count))
Map <- left_join(Map, map, by = c("ARS" = "Heimkreis"))
my_breaks <- c(0,0.1,0.3,0.9,2.7,8.1)
ggplot(Map) + geom_sf(aes(fill=Matches_per_Einwohner)) + theme_void() + scale_fill_gradient(name = "", trans = "log", breaks = my_breaks, labels = my_breaks, low="lightblue", high="darkblue") + labs(title = "Matches per 100,000 Inhabitants") + theme(plot.title = element_text(hjust = 0.5))
my_breaks <- c(0,2,10,50,250,1250,6000)
ggplot(Map) + geom_sf(aes(fill=Visitors_per_Einwohner)) + theme_void() + scale_fill_gradient(name = "", trans = "log", breaks = my_breaks, labels = my_breaks, low="lightblue", high="darkblue") + labs(title = "Visitors per 100,000 Inhabitants") + theme(plot.title = element_text(hjust = 0.5))
my_breaks <- c(0,100,300,600,900,1200)
ggplot(Map) + geom_sf(aes(fill=Incidence)) + theme_void() + scale_fill_gradient(name = "", trans = "log", breaks = my_breaks, labels = my_breaks, low="lightblue", high="darkblue") + labs(title = "Cases per 100,000 Inhabitants (Aug. 10 - Nov. 08)") + theme(plot.title = element_text(hjust = 0.5))
my_breaks <- c(0,0.2, 0.4, 0.6, 0.8, 1)
ggplot(Map) + geom_sf(aes(fill=share_visitors)) + theme_void() + scale_fill_gradient(name = "", breaks = my_breaks, labels = my_breaks, low="lightblue", high="darkblue") + labs(title = "Share of Matches with Visitors") + theme(plot.title = element_text(hjust = 0.5))