## Replication Figure A11-A12

# Load Packages
library(readr)
library(readxl)
library(dplyr)
library(ggplot2)
library(lmtest)
library(stargazer)
library(sandwich)
library(lubridate)
library(AER)
library(scales)
library(pscl)
library(plm)
library(urca)
library(tseries)
library(EventStudy)
library(gridExtra)
library(mfx)
library(stringr)
library(sf)
library(fixest)

# Set Working Directory to the 'Data' Folder of the Replication Package
setwd("XXX")

# Load Data
Panel <- read_csv("Panelhet.csv")
Panel <- as.data.frame(Panel[,-1])
Spiele_2 <- read_xlsx("Spiele.xlsx")
Stadien <- read_xlsx("Stadien.xlsx")

Panel$Spiel <- NULL
Panel$Zuschauer <- NULL
Spiele_2$Spiel <- 1
Spiele_2 <- group_by(left_join(Spiele_2, filter(Stadien, Saison=="2019/2020"), by = c("Stadion" = "Club")), Heimkreis, Datum)
Spiele_2$Auslastung <- Spiele_2$Zuschauer/Spiele_2$Capacity
Spiele_2$Auslastung[is.na(Spiele_2$Auslastung)] <- 0
Spiele_2 <- filter(Spiele_2, Zuschauer>0)
Spiele_2 <- left_join(Spiele_2, dplyr::select(Panel, IdLandkreis, Meldedatum, Inzidenz_Faelle), by = c("Datum" = "Meldedatum", "Heimkreis" = "IdLandkreis"))
Spiele_2 <- filter(Spiele_2, Inzidenz_Faelle<35)
Spiele_2$Occupancy <- 0
Spiele_2$Occupancy[Spiele_2$Auslastung<0.05] <- "0-5%"
Spiele_2$Occupancy[Spiele_2$Auslastung<=0.1 & Spiele_2$Auslastung>=0.05] <- "5-10%"
Spiele_2$Occupancy[Spiele_2$Auslastung<=0.15 & Spiele_2$Auslastung>=0.1] <- "10-15%"
Spiele_2$Occupancy[Spiele_2$Auslastung>0.15] <- "15%+"
Spiele_2 <- group_by(Spiele_2, Heimkreis, Datum, Occupancy)
Spiele_2 <- summarize(Spiele_2, Spiel=sum(Spiel), Zuschauer=sum(Zuschauer))
Panel <- left_join(Panel, dplyr::select(Spiele_2[Spiele_2$Occupancy=="0-5%",], Heimkreis, Spiel, Zuschauer), by = c("IdLandkreis" = "Heimkreis", "Meldedatum" = "Datum"))
Panel$Spiel_05 <- Panel$Spiel
Panel$Spiel_05[is.na(Panel$Spiel_05)] <- 0
Panel$Spiel <- NULL
Panel$Zuschauer_05 <- Panel$Zuschauer
Panel$Zuschauer_05[is.na(Panel$Zuschauer_05)] <- 0
Panel$Zuschauer <- NULL
Panel <- left_join(Panel, dplyr::select(Spiele_2[Spiele_2$Occupancy=="5-10%",], Heimkreis, Spiel, Zuschauer), by = c("IdLandkreis" = "Heimkreis", "Meldedatum" = "Datum"))
Panel$Spiel_510 <- Panel$Spiel
Panel$Spiel_510[is.na(Panel$Spiel_510)] <- 0
Panel$Spiel <- NULL
Panel$Zuschauer_510 <- Panel$Zuschauer
Panel$Zuschauer_510[is.na(Panel$Zuschauer_510)] <- 0
Panel$Zuschauer <- NULL
Panel <- left_join(Panel, dplyr::select(Spiele_2[Spiele_2$Occupancy=="10-15%",], Heimkreis, Spiel, Zuschauer), by = c("IdLandkreis" = "Heimkreis", "Meldedatum" = "Datum"))
Panel$Spiel_1015 <- Panel$Spiel
Panel$Spiel_1015[is.na(Panel$Spiel_1015)] <- 0
Panel$Spiel <- NULL
Panel$Zuschauer_1015 <- Panel$Zuschauer
Panel$Zuschauer_1015[is.na(Panel$Zuschauer_1015)] <- 0
Panel$Zuschauer <- NULL
Panel <- left_join(Panel, dplyr::select(Spiele_2[Spiele_2$Occupancy=="15%+",], Heimkreis, Spiel, Zuschauer), by = c("IdLandkreis" = "Heimkreis", "Meldedatum" = "Datum"))
Panel$Spiel_15 <- Panel$Spiel
Panel$Spiel_15[is.na(Panel$Spiel_15)] <- 0
Panel$Spiel <- NULL
Panel$Zuschauer_15 <- Panel$Zuschauer
Panel$Zuschauer_15[is.na(Panel$Zuschauer_15)] <- 0
Panel$Zuschauer <- NULL
################################# Regression (Matches up to 5%) ################
Panel[,74:95] <- 0
Panel$Spiel_pro_Einwohner <- Panel$Spiel_05/Panel$Einwohner*100000
for (i in 1:22){
  a <- i
  b <- 73+i
  Panel[,b] <- dplyr::lag(Panel$Spiel_pro_Einwohner, a)
  Panel$lag_Kreis <- dplyr::lag(Panel$IdLandkreis, a)
  Panel[,b][Panel$lag_Kreis!=Panel$IdLandkreis] <- 0
  Panel[,b][is.na(Panel[,b])] <- 0
}
Panel[,97:111] <- 0
for (i in 1:15){
  a <- i
  b <- 96+i
  Panel[,b] <- dplyr::lead(Panel$Spiel_pro_Einwohner, a)
  Panel$lag_Kreis <- dplyr::lead(Panel$IdLandkreis, a)
  Panel[,b][Panel$lag_Kreis!=Panel$IdLandkreis] <- 0
  Panel[,b][is.na(Panel[,b])] <- 0
}
Panel$Faelle_pro_Einwohner <- Panel$Faelle/as.numeric(Panel$Einwohner)*100000
Panel$vorher_22[is.na(Panel$vorher_22)] <- 0
Panel$danach_15[is.na(Panel$danach_15)] <- 0
for (i in unique(Panel$IdLandkreis)){
  a <- Panel[Panel$IdLandkreis==i,]
  a$vorher_22 <- cumsum(a$vorher_22)
  Panel$vorher_22[Panel$IdLandkreis==i] <- a$vorher_22
}
for (i in unique(Panel$IdLandkreis)){
  a <- Panel[Panel$IdLandkreis==i,]
  a$danach_15 <- rev(cumsum(rev(a$danach_15)))
  Panel$danach_15[Panel$IdLandkreis==i] <- a$danach_15
}
# Binned Results
Panel$vorher0103 <- Panel$vorher_01+Panel$vorher_02+Panel$vorher_03
Panel$vorher0406 <- Panel$vorher_04+Panel$vorher_05+Panel$vorher_06
Panel$vorher0709 <- Panel$vorher_07+Panel$vorher_08+Panel$vorher_09
Panel$vorher1012 <- Panel$vorher_10+Panel$vorher_11+Panel$vorher_12
Panel$vorher1315 <- Panel$vorher_13+Panel$vorher_14+Panel$vorher_15
Panel$vorher1618 <- Panel$vorher_16+Panel$vorher_17+Panel$vorher_18
Panel$vorher1921 <- Panel$vorher_19+Panel$vorher_20+Panel$vorher_21
Panel$danach0103 <- Panel$danach_01+Panel$danach_02+Panel$danach_03
Panel$danach0406 <- Panel$danach_04+Panel$danach_05+Panel$danach_06
Panel$danach0709 <- Panel$danach_07+Panel$danach_08+Panel$danach_09
Panel$danach1012 <- Panel$danach_10+Panel$danach_11+Panel$danach_12
Panel$danach1314 <- Panel$danach_13+Panel$danach_14
Panel$stateweek <- paste(Panel$state, Panel$week)
reg1 <- summary(feols(Faelle_pro_Einwohner ~ vorher0103 + vorher0406 + vorher0709 + vorher1012 + vorher1315 + vorher1618 + vorher1921 + vorher_22 +
                        danach0103 + danach0406 + danach0709 + danach1012 + danach1314 + danach_15 + parks + grocery + retail + stations + workplaces + residential    | IdLandkreis + Meldedatum + stateweek  +0, Panel[Panel$Meldedatum>"2020-08-09" & Panel$Meldedatum<"2020-11-09",], cluster= ~IdLandkreis))
coefficient <- reg1$coefficients[c(1:7,9:13)]
st_error <- reg1$se[c(1:7,9:13)]*1.96
timing <- c(" [1,3]", " [4,6]", " [7,9]", "[10,12]", "[13,15]","[16,18]", "[19,21]", " [-3,-1]", "  [-6,-4]", "   [-9,-7]", "   [-12,-10]", "    [-14,-13]")
data <- as.data.frame(cbind(coefficient, st_error, timing))
data[13,] <- c(0,0," [0]")
data$coefficient <- as.numeric(data$coefficient)
data$st_error <- as.numeric(data$st_error)

# Figure A11: Left Top Plot
ggplot(data, aes(x=timing)) + geom_ribbon(aes(ymin=coefficient-st_error, ymax=coefficient+st_error), alpha=0.2, fill="blue", group=1) + geom_ribbon(aes(ymin=coefficient-st_error/1.959964*1.64, ymax=coefficient+st_error/1.959964*1.64), alpha=0.35, fill="blue", group=1) + geom_point(aes(y=coefficient), col="navyblue", size=2) + geom_line(aes(y=coefficient), col="navyblue", size=0.5, group=1) + theme_classic() + geom_hline(yintercept=0, linetype="dashed") + geom_vline(xintercept=6, linetype="dashed") + labs(y="Daily Cases per 100,000", x="Days") + ylim(-2.5,5.5)

########################## Regression (Match 5-10%) ######################
Panel[,74:95] <- 0
Panel$Spiel_pro_Einwohner <- Panel$Spiel_510/Panel$Einwohner*100000
for (i in 1:22){
  a <- i
  b <- 73+i
  Panel[,b] <- dplyr::lag(Panel$Spiel_pro_Einwohner, a)
  Panel$lag_Kreis <- dplyr::lag(Panel$IdLandkreis, a)
  Panel[,b][Panel$lag_Kreis!=Panel$IdLandkreis] <- 0
  Panel[,b][is.na(Panel[,b])] <- 0
}
Panel[,97:111] <- 0
for (i in 1:15){
  a <- i
  b <- 96+i
  Panel[,b] <- dplyr::lead(Panel$Spiel_pro_Einwohner, a)
  Panel$lag_Kreis <- dplyr::lead(Panel$IdLandkreis, a)
  Panel[,b][Panel$lag_Kreis!=Panel$IdLandkreis] <- 0
  Panel[,b][is.na(Panel[,b])] <- 0
}
Panel$Faelle_pro_Einwohner <- Panel$Faelle/as.numeric(Panel$Einwohner)*100000
Panel$vorher_22[is.na(Panel$vorher_22)] <- 0
Panel$danach_15[is.na(Panel$danach_15)] <- 0
for (i in unique(Panel$IdLandkreis)){
  a <- Panel[Panel$IdLandkreis==i,]
  a$vorher_22 <- cumsum(a$vorher_22)
  Panel$vorher_22[Panel$IdLandkreis==i] <- a$vorher_22
}
for (i in unique(Panel$IdLandkreis)){
  a <- Panel[Panel$IdLandkreis==i,]
  a$danach_15 <- rev(cumsum(rev(a$danach_15)))
  Panel$danach_15[Panel$IdLandkreis==i] <- a$danach_15
}
# Binned Results
Panel$vorher0103 <- Panel$vorher_01+Panel$vorher_02+Panel$vorher_03
Panel$vorher0406 <- Panel$vorher_04+Panel$vorher_05+Panel$vorher_06
Panel$vorher0709 <- Panel$vorher_07+Panel$vorher_08+Panel$vorher_09
Panel$vorher1012 <- Panel$vorher_10+Panel$vorher_11+Panel$vorher_12
Panel$vorher1315 <- Panel$vorher_13+Panel$vorher_14+Panel$vorher_15
Panel$vorher1618 <- Panel$vorher_16+Panel$vorher_17+Panel$vorher_18
Panel$vorher1921 <- Panel$vorher_19+Panel$vorher_20+Panel$vorher_21
Panel$danach0103 <- Panel$danach_01+Panel$danach_02+Panel$danach_03
Panel$danach0406 <- Panel$danach_04+Panel$danach_05+Panel$danach_06
Panel$danach0709 <- Panel$danach_07+Panel$danach_08+Panel$danach_09
Panel$danach1012 <- Panel$danach_10+Panel$danach_11+Panel$danach_12
Panel$danach1314 <- Panel$danach_13+Panel$danach_14
Panel$stateweek <- paste(Panel$state, Panel$week)
reg1 <- summary(feols(Faelle_pro_Einwohner ~ vorher0103 + vorher0406 + vorher0709 + vorher1012 + vorher1315 + vorher1618 + vorher1921 + vorher_22 +
                        danach0103 + danach0406 + danach0709 + danach1012 + danach1314 + danach_15 + parks + grocery + retail + stations + workplaces + residential    | IdLandkreis + Meldedatum + stateweek  +0, Panel[Panel$Meldedatum>"2020-08-09" & Panel$Meldedatum<"2020-11-09",], cluster= ~IdLandkreis))
coefficient <- reg1$coefficients[c(1:7,9:13)]
st_error <- reg1$se[c(1:7,9:13)]*1.96
timing <- c(" [1,3]", " [4,6]", " [7,9]", "[10,12]", "[13,15]","[16,18]", "[19,21]", " [-3,-1]", "  [-6,-4]", "   [-9,-7]", "   [-12,-10]", "    [-14,-13]")
data <- as.data.frame(cbind(coefficient, st_error, timing))
data[13,] <- c(0,0," [0]")
data$coefficient <- as.numeric(data$coefficient)
data$st_error <- as.numeric(data$st_error)

# Figure A11: Right Top Plot
ggplot(data, aes(x=timing)) + geom_ribbon(aes(ymin=coefficient-st_error, ymax=coefficient+st_error), alpha=0.2, fill="blue", group=1) + geom_ribbon(aes(ymin=coefficient-st_error/1.959964*1.64, ymax=coefficient+st_error/1.959964*1.64), alpha=0.35, fill="blue", group=1) + geom_point(aes(y=coefficient), col="navyblue", size=2) + geom_line(aes(y=coefficient), col="navyblue", size=0.5, group=1) + theme_classic() + geom_hline(yintercept=0, linetype="dashed") + geom_vline(xintercept=6, linetype="dashed") + labs(y="Daily Cases per 100,000", x="Days") + ylim(-2.5,5.5)

########################## Regression (Match 10-15%) ######################
Panel[,74:95] <- 0
Panel$Spiel_pro_Einwohner <- Panel$Spiel_1015/Panel$Einwohner*100000
for (i in 1:22){
  a <- i
  b <- 73+i
  Panel[,b] <- dplyr::lag(Panel$Spiel_pro_Einwohner, a)
  Panel$lag_Kreis <- dplyr::lag(Panel$IdLandkreis, a)
  Panel[,b][Panel$lag_Kreis!=Panel$IdLandkreis] <- 0
  Panel[,b][is.na(Panel[,b])] <- 0
}
Panel[,97:111] <- 0
for (i in 1:15){
  a <- i
  b <- 96+i
  Panel[,b] <- dplyr::lead(Panel$Spiel_pro_Einwohner, a)
  Panel$lag_Kreis <- dplyr::lead(Panel$IdLandkreis, a)
  Panel[,b][Panel$lag_Kreis!=Panel$IdLandkreis] <- 0
  Panel[,b][is.na(Panel[,b])] <- 0
}
Panel$Faelle_pro_Einwohner <- Panel$Faelle/as.numeric(Panel$Einwohner)*100000
Panel$vorher_22[is.na(Panel$vorher_22)] <- 0
Panel$danach_15[is.na(Panel$danach_15)] <- 0
for (i in unique(Panel$IdLandkreis)){
  a <- Panel[Panel$IdLandkreis==i,]
  a$vorher_22 <- cumsum(a$vorher_22)
  Panel$vorher_22[Panel$IdLandkreis==i] <- a$vorher_22
}
for (i in unique(Panel$IdLandkreis)){
  a <- Panel[Panel$IdLandkreis==i,]
  a$danach_15 <- rev(cumsum(rev(a$danach_15)))
  Panel$danach_15[Panel$IdLandkreis==i] <- a$danach_15
}
# Binned Results
Panel$vorher0103 <- Panel$vorher_01+Panel$vorher_02+Panel$vorher_03
Panel$vorher0406 <- Panel$vorher_04+Panel$vorher_05+Panel$vorher_06
Panel$vorher0709 <- Panel$vorher_07+Panel$vorher_08+Panel$vorher_09
Panel$vorher1012 <- Panel$vorher_10+Panel$vorher_11+Panel$vorher_12
Panel$vorher1315 <- Panel$vorher_13+Panel$vorher_14+Panel$vorher_15
Panel$vorher1618 <- Panel$vorher_16+Panel$vorher_17+Panel$vorher_18
Panel$vorher1921 <- Panel$vorher_19+Panel$vorher_20+Panel$vorher_21
Panel$danach0103 <- Panel$danach_01+Panel$danach_02+Panel$danach_03
Panel$danach0406 <- Panel$danach_04+Panel$danach_05+Panel$danach_06
Panel$danach0709 <- Panel$danach_07+Panel$danach_08+Panel$danach_09
Panel$danach1012 <- Panel$danach_10+Panel$danach_11+Panel$danach_12
Panel$danach1314 <- Panel$danach_13+Panel$danach_14
Panel$stateweek <- paste(Panel$state, Panel$week)
reg1 <- summary(feols(Faelle_pro_Einwohner ~ vorher0103 + vorher0406 + vorher0709 + vorher1012 + vorher1315 + vorher1618 + vorher1921 + vorher_22 +
                        danach0103 + danach0406 + danach0709 + danach1012 + danach1314 + danach_15 + parks + grocery + retail + stations + workplaces + residential    | IdLandkreis + Meldedatum + stateweek  +0, Panel[Panel$Meldedatum>"2020-08-09" & Panel$Meldedatum<"2020-11-09",], cluster= ~IdLandkreis))
coefficient <- reg1$coefficients[c(1:7,9:13)]
st_error <- reg1$se[c(1:7,9:13)]*1.96
timing <- c(" [1,3]", " [4,6]", " [7,9]", "[10,12]", "[13,15]","[16,18]", "[19,21]", " [-3,-1]", "  [-6,-4]", "   [-9,-7]", "   [-12,-10]", "    [-14,-13]")
data <- as.data.frame(cbind(coefficient, st_error, timing))
data[13,] <- c(0,0," [0]")
data$coefficient <- as.numeric(data$coefficient)
data$st_error <- as.numeric(data$st_error)

# Figure A11: Left Bottom Plot
ggplot(data, aes(x=timing)) + geom_ribbon(aes(ymin=coefficient-st_error, ymax=coefficient+st_error), alpha=0.2, fill="blue", group=1) + geom_ribbon(aes(ymin=coefficient-st_error/1.959964*1.64, ymax=coefficient+st_error/1.959964*1.64), alpha=0.35, fill="blue", group=1) + geom_point(aes(y=coefficient), col="navyblue", size=2) + geom_line(aes(y=coefficient), col="navyblue", size=0.5, group=1) + theme_classic() + geom_hline(yintercept=0, linetype="dashed") + geom_vline(xintercept=6, linetype="dashed") + labs(y="Daily Cases per 100,000", x="Days") + ylim(-2.5,5.5)

########################## Regression (Match above 15%) ######################
Panel[,74:95] <- 0
Panel$Spiel_pro_Einwohner <- Panel$Spiel_15/Panel$Einwohner*100000
for (i in 1:22){
  a <- i
  b <- 73+i
  Panel[,b] <- dplyr::lag(Panel$Spiel_pro_Einwohner, a)
  Panel$lag_Kreis <- dplyr::lag(Panel$IdLandkreis, a)
  Panel[,b][Panel$lag_Kreis!=Panel$IdLandkreis] <- 0
  Panel[,b][is.na(Panel[,b])] <- 0
}
Panel[,97:111] <- 0
for (i in 1:15){
  a <- i
  b <- 96+i
  Panel[,b] <- dplyr::lead(Panel$Spiel_pro_Einwohner, a)
  Panel$lag_Kreis <- dplyr::lead(Panel$IdLandkreis, a)
  Panel[,b][Panel$lag_Kreis!=Panel$IdLandkreis] <- 0
  Panel[,b][is.na(Panel[,b])] <- 0
}
Panel$Faelle_pro_Einwohner <- Panel$Faelle/as.numeric(Panel$Einwohner)*100000
Panel$vorher_22[is.na(Panel$vorher_22)] <- 0
Panel$danach_15[is.na(Panel$danach_15)] <- 0
for (i in unique(Panel$IdLandkreis)){
  a <- Panel[Panel$IdLandkreis==i,]
  a$vorher_22 <- cumsum(a$vorher_22)
  Panel$vorher_22[Panel$IdLandkreis==i] <- a$vorher_22
}
for (i in unique(Panel$IdLandkreis)){
  a <- Panel[Panel$IdLandkreis==i,]
  a$danach_15 <- rev(cumsum(rev(a$danach_15)))
  Panel$danach_15[Panel$IdLandkreis==i] <- a$danach_15
}
# Binned Results
Panel$vorher0103 <- Panel$vorher_01+Panel$vorher_02+Panel$vorher_03
Panel$vorher0406 <- Panel$vorher_04+Panel$vorher_05+Panel$vorher_06
Panel$vorher0709 <- Panel$vorher_07+Panel$vorher_08+Panel$vorher_09
Panel$vorher1012 <- Panel$vorher_10+Panel$vorher_11+Panel$vorher_12
Panel$vorher1315 <- Panel$vorher_13+Panel$vorher_14+Panel$vorher_15
Panel$vorher1618 <- Panel$vorher_16+Panel$vorher_17+Panel$vorher_18
Panel$vorher1921 <- Panel$vorher_19+Panel$vorher_20+Panel$vorher_21
Panel$danach0103 <- Panel$danach_01+Panel$danach_02+Panel$danach_03
Panel$danach0406 <- Panel$danach_04+Panel$danach_05+Panel$danach_06
Panel$danach0709 <- Panel$danach_07+Panel$danach_08+Panel$danach_09
Panel$danach1012 <- Panel$danach_10+Panel$danach_11+Panel$danach_12
Panel$danach1314 <- Panel$danach_13+Panel$danach_14
Panel$stateweek <- paste(Panel$state, Panel$week)
reg1 <- summary(feols(Faelle_pro_Einwohner ~ vorher0103 + vorher0406 + vorher0709 + vorher1012 + vorher1315 + vorher1618 + vorher1921 + vorher_22 +
                        danach0103 + danach0406 + danach0709 + danach1012 + danach1314 + danach_15 + parks + grocery + retail + stations + workplaces + residential    | IdLandkreis + Meldedatum + stateweek  +0, Panel[Panel$Meldedatum>"2020-08-09" & Panel$Meldedatum<"2020-11-09",], cluster= ~IdLandkreis))
coefficient <- reg1$coefficients[c(1:7,9:13)]
st_error <- reg1$se[c(1:7,9:13)]*1.96
timing <- c(" [1,3]", " [4,6]", " [7,9]", "[10,12]", "[13,15]","[16,18]", "[19,21]", " [-3,-1]", "  [-6,-4]", "   [-9,-7]", "   [-12,-10]", "    [-14,-13]")
data <- as.data.frame(cbind(coefficient, st_error, timing))
data[13,] <- c(0,0," [0]")
data$coefficient <- as.numeric(data$coefficient)
data$st_error <- as.numeric(data$st_error)

# Figure A11: Right Bottom Plot
ggplot(data, aes(x=timing)) + geom_ribbon(aes(ymin=coefficient-st_error, ymax=coefficient+st_error), alpha=0.2, fill="blue", group=1) + geom_ribbon(aes(ymin=coefficient-st_error/1.959964*1.64, ymax=coefficient+st_error/1.959964*1.64), alpha=0.35, fill="blue", group=1) + geom_point(aes(y=coefficient), col="navyblue", size=2) + geom_line(aes(y=coefficient), col="navyblue", size=0.5, group=1) + theme_classic() + geom_hline(yintercept=0, linetype="dashed") + geom_vline(xintercept=6, linetype="dashed") + labs(y="Daily Cases per 100,000", x="Days") + ylim(-3.5,5.5)

################################################################# Occupancy (Zuschauer) #######################################################
################################# Regression (Matches up to 5%) ################
Panel[,74:95] <- 0
Panel$Spiel_pro_Einwohner <- Panel$Zuschauer_05/Panel$Einwohner*100000
#Panel$Spiel_pro_Einwohner <- scale(Panel$Spiel_pro_Einwohner)
for (i in 1:22){
  a <- i
  b <- 73+i
  Panel[,b] <- dplyr::lag(Panel$Spiel_pro_Einwohner, a)
  Panel$lag_Kreis <- dplyr::lag(Panel$IdLandkreis, a)
  Panel[,b][Panel$lag_Kreis!=Panel$IdLandkreis] <- 0
  Panel[,b][is.na(Panel[,b])] <- 0
}
Panel[,97:111] <- 0
for (i in 1:15){
  a <- i
  b <- 96+i
  Panel[,b] <- dplyr::lead(Panel$Spiel_pro_Einwohner, a)
  Panel$lag_Kreis <- dplyr::lead(Panel$IdLandkreis, a)
  Panel[,b][Panel$lag_Kreis!=Panel$IdLandkreis] <- 0
  Panel[,b][is.na(Panel[,b])] <- 0
}
Panel$Faelle_pro_Einwohner <- Panel$Faelle/as.numeric(Panel$Einwohner)*100000
Panel$vorher_22[is.na(Panel$vorher_22)] <- 0
Panel$danach_15[is.na(Panel$danach_15)] <- 0
for (i in unique(Panel$IdLandkreis)){
  a <- Panel[Panel$IdLandkreis==i,]
  a$vorher_22 <- cumsum(a$vorher_22)
  Panel$vorher_22[Panel$IdLandkreis==i] <- a$vorher_22
}
for (i in unique(Panel$IdLandkreis)){
  a <- Panel[Panel$IdLandkreis==i,]
  a$danach_15 <- rev(cumsum(rev(a$danach_15)))
  Panel$danach_15[Panel$IdLandkreis==i] <- a$danach_15
}
# Binned Results
Panel$vorher0103 <- Panel$vorher_01+Panel$vorher_02+Panel$vorher_03
Panel$vorher0406 <- Panel$vorher_04+Panel$vorher_05+Panel$vorher_06
Panel$vorher0709 <- Panel$vorher_07+Panel$vorher_08+Panel$vorher_09
Panel$vorher1012 <- Panel$vorher_10+Panel$vorher_11+Panel$vorher_12
Panel$vorher1315 <- Panel$vorher_13+Panel$vorher_14+Panel$vorher_15
Panel$vorher1618 <- Panel$vorher_16+Panel$vorher_17+Panel$vorher_18
Panel$vorher1921 <- Panel$vorher_19+Panel$vorher_20+Panel$vorher_21
Panel$danach0103 <- Panel$danach_01+Panel$danach_02+Panel$danach_03
Panel$danach0406 <- Panel$danach_04+Panel$danach_05+Panel$danach_06
Panel$danach0709 <- Panel$danach_07+Panel$danach_08+Panel$danach_09
Panel$danach1012 <- Panel$danach_10+Panel$danach_11+Panel$danach_12
Panel$danach1314 <- Panel$danach_13+Panel$danach_14
Panel$stateweek <- paste(Panel$state, Panel$week)
reg1 <- summary(feols(Faelle_pro_Einwohner ~ vorher0103 + vorher0406 + vorher0709 + vorher1012 + vorher1315 + vorher1618 + vorher1921 + vorher_22 +
                        danach0103 + danach0406 + danach0709 + danach1012 + danach1314 + danach_15 + parks + grocery + retail + stations + workplaces + residential    | IdLandkreis + Meldedatum + stateweek  +0, Panel[Panel$Meldedatum>"2020-08-09" & Panel$Meldedatum<"2020-11-09",], cluster= ~IdLandkreis))
coefficient <- reg1$coefficients[c(1:7,9:13)]
st_error <- reg1$se[c(1:7,9:13)]*1.96
timing <- c(" [1,3]", " [4,6]", " [7,9]", "[10,12]", "[13,15]","[16,18]", "[19,21]", " [-3,-1]", "  [-6,-4]", "   [-9,-7]", "   [-12,-10]", "    [-14,-13]")
data <- as.data.frame(cbind(coefficient, st_error, timing))
data[13,] <- c(0,0," [0]")
data$coefficient <- as.numeric(data$coefficient)
data$st_error <- as.numeric(data$st_error)

# Figure A12: Left Top Plot
ggplot(data, aes(x=timing)) + geom_ribbon(aes(ymin=coefficient-st_error, ymax=coefficient+st_error), alpha=0.2, fill="blue", group=1) + geom_ribbon(aes(ymin=coefficient-st_error/1.959964*1.64, ymax=coefficient+st_error/1.959964*1.64), alpha=0.35, fill="blue", group=1) + geom_point(aes(y=coefficient), col="navyblue", size=2) + geom_line(aes(y=coefficient), col="navyblue", size=0.5, group=1) + theme_classic() + geom_hline(yintercept=0, linetype="dashed") + geom_vline(xintercept=6, linetype="dashed") + labs(y="Daily Cases per 100,000", x="Days") + ylim(-0.003,0.006)

########################## Regression (Match 5-10%) ######################
Panel[,74:95] <- 0
Panel$Spiel_pro_Einwohner <- Panel$Zuschauer_510/Panel$Einwohner*100000
#Panel$Spiel_pro_Einwohner <- scale(Panel$Spiel_pro_Einwohner)
for (i in 1:22){
  a <- i
  b <- 73+i
  Panel[,b] <- dplyr::lag(Panel$Spiel_pro_Einwohner, a)
  Panel$lag_Kreis <- dplyr::lag(Panel$IdLandkreis, a)
  Panel[,b][Panel$lag_Kreis!=Panel$IdLandkreis] <- 0
  Panel[,b][is.na(Panel[,b])] <- 0
}
Panel[,97:111] <- 0
for (i in 1:15){
  a <- i
  b <- 96+i
  Panel[,b] <- dplyr::lead(Panel$Spiel_pro_Einwohner, a)
  Panel$lag_Kreis <- dplyr::lead(Panel$IdLandkreis, a)
  Panel[,b][Panel$lag_Kreis!=Panel$IdLandkreis] <- 0
  Panel[,b][is.na(Panel[,b])] <- 0
}
Panel$Faelle_pro_Einwohner <- Panel$Faelle/as.numeric(Panel$Einwohner)*100000
Panel$vorher_22[is.na(Panel$vorher_22)] <- 0
Panel$danach_15[is.na(Panel$danach_15)] <- 0
for (i in unique(Panel$IdLandkreis)){
  a <- Panel[Panel$IdLandkreis==i,]
  a$vorher_22 <- cumsum(a$vorher_22)
  Panel$vorher_22[Panel$IdLandkreis==i] <- a$vorher_22
}
for (i in unique(Panel$IdLandkreis)){
  a <- Panel[Panel$IdLandkreis==i,]
  a$danach_15 <- rev(cumsum(rev(a$danach_15)))
  Panel$danach_15[Panel$IdLandkreis==i] <- a$danach_15
}
# Binned Results
Panel$vorher0103 <- Panel$vorher_01+Panel$vorher_02+Panel$vorher_03
Panel$vorher0406 <- Panel$vorher_04+Panel$vorher_05+Panel$vorher_06
Panel$vorher0709 <- Panel$vorher_07+Panel$vorher_08+Panel$vorher_09
Panel$vorher1012 <- Panel$vorher_10+Panel$vorher_11+Panel$vorher_12
Panel$vorher1315 <- Panel$vorher_13+Panel$vorher_14+Panel$vorher_15
Panel$vorher1618 <- Panel$vorher_16+Panel$vorher_17+Panel$vorher_18
Panel$vorher1921 <- Panel$vorher_19+Panel$vorher_20+Panel$vorher_21
Panel$danach0103 <- Panel$danach_01+Panel$danach_02+Panel$danach_03
Panel$danach0406 <- Panel$danach_04+Panel$danach_05+Panel$danach_06
Panel$danach0709 <- Panel$danach_07+Panel$danach_08+Panel$danach_09
Panel$danach1012 <- Panel$danach_10+Panel$danach_11+Panel$danach_12
Panel$danach1314 <- Panel$danach_13+Panel$danach_14
Panel$stateweek <- paste(Panel$state, Panel$week)
reg1 <- summary(feols(Faelle_pro_Einwohner ~ vorher0103 + vorher0406 + vorher0709 + vorher1012 + vorher1315 + vorher1618 + vorher1921 + vorher_22 +
                        danach0103 + danach0406 + danach0709 + danach1012 + danach1314 + danach_15 + parks + grocery + retail + stations + workplaces + residential    | IdLandkreis + Meldedatum + stateweek  +0, Panel[Panel$Meldedatum>"2020-08-09" & Panel$Meldedatum<"2020-11-09",], cluster= ~IdLandkreis))
coefficient <- reg1$coefficients[c(1:7,9:13)]
st_error <- reg1$se[c(1:7,9:13)]*1.96
timing <- c(" [1,3]", " [4,6]", " [7,9]", "[10,12]", "[13,15]","[16,18]", "[19,21]", " [-3,-1]", "  [-6,-4]", "   [-9,-7]", "   [-12,-10]", "    [-14,-13]")
data <- as.data.frame(cbind(coefficient, st_error, timing))
data[13,] <- c(0,0," [0]")
data$coefficient <- as.numeric(data$coefficient)
data$st_error <- as.numeric(data$st_error)

# Figure A12: Right Top Plot
ggplot(data, aes(x=timing)) + geom_ribbon(aes(ymin=coefficient-st_error, ymax=coefficient+st_error), alpha=0.2, fill="blue", group=1) + geom_ribbon(aes(ymin=coefficient-st_error/1.959964*1.64, ymax=coefficient+st_error/1.959964*1.64), alpha=0.35, fill="blue", group=1) + geom_point(aes(y=coefficient), col="navyblue", size=2) + geom_line(aes(y=coefficient), col="navyblue", size=0.5, group=1) + theme_classic() + geom_hline(yintercept=0, linetype="dashed") + geom_vline(xintercept=6, linetype="dashed") + labs(y="Daily Cases per 100,000", x="Days") + ylim(-0.003,0.006)

########################## Regression (Match 10-15%) ######################
Panel[,74:95] <- 0
Panel$Spiel_pro_Einwohner <- Panel$Zuschauer_1015/Panel$Einwohner*100000
#Panel$Spiel_pro_Einwohner <- scale(Panel$Spiel_pro_Einwohner)
for (i in 1:22){
  a <- i
  b <- 73+i
  Panel[,b] <- dplyr::lag(Panel$Spiel_pro_Einwohner, a)
  Panel$lag_Kreis <- dplyr::lag(Panel$IdLandkreis, a)
  Panel[,b][Panel$lag_Kreis!=Panel$IdLandkreis] <- 0
  Panel[,b][is.na(Panel[,b])] <- 0
}
Panel[,97:111] <- 0
for (i in 1:15){
  a <- i
  b <- 96+i
  Panel[,b] <- dplyr::lead(Panel$Spiel_pro_Einwohner, a)
  Panel$lag_Kreis <- dplyr::lead(Panel$IdLandkreis, a)
  Panel[,b][Panel$lag_Kreis!=Panel$IdLandkreis] <- 0
  Panel[,b][is.na(Panel[,b])] <- 0
}
Panel$Faelle_pro_Einwohner <- Panel$Faelle/as.numeric(Panel$Einwohner)*100000
Panel$vorher_22[is.na(Panel$vorher_22)] <- 0
Panel$danach_15[is.na(Panel$danach_15)] <- 0
for (i in unique(Panel$IdLandkreis)){
  a <- Panel[Panel$IdLandkreis==i,]
  a$vorher_22 <- cumsum(a$vorher_22)
  Panel$vorher_22[Panel$IdLandkreis==i] <- a$vorher_22
}
for (i in unique(Panel$IdLandkreis)){
  a <- Panel[Panel$IdLandkreis==i,]
  a$danach_15 <- rev(cumsum(rev(a$danach_15)))
  Panel$danach_15[Panel$IdLandkreis==i] <- a$danach_15
}
# Binned Results
Panel$vorher0103 <- Panel$vorher_01+Panel$vorher_02+Panel$vorher_03
Panel$vorher0406 <- Panel$vorher_04+Panel$vorher_05+Panel$vorher_06
Panel$vorher0709 <- Panel$vorher_07+Panel$vorher_08+Panel$vorher_09
Panel$vorher1012 <- Panel$vorher_10+Panel$vorher_11+Panel$vorher_12
Panel$vorher1315 <- Panel$vorher_13+Panel$vorher_14+Panel$vorher_15
Panel$vorher1618 <- Panel$vorher_16+Panel$vorher_17+Panel$vorher_18
Panel$vorher1921 <- Panel$vorher_19+Panel$vorher_20+Panel$vorher_21
Panel$danach0103 <- Panel$danach_01+Panel$danach_02+Panel$danach_03
Panel$danach0406 <- Panel$danach_04+Panel$danach_05+Panel$danach_06
Panel$danach0709 <- Panel$danach_07+Panel$danach_08+Panel$danach_09
Panel$danach1012 <- Panel$danach_10+Panel$danach_11+Panel$danach_12
Panel$danach1314 <- Panel$danach_13+Panel$danach_14
Panel$stateweek <- paste(Panel$state, Panel$week)
reg1 <- summary(feols(Faelle_pro_Einwohner ~ vorher0103 + vorher0406 + vorher0709 + vorher1012 + vorher1315 + vorher1618 + vorher1921 + vorher_22 +
                        danach0103 + danach0406 + danach0709 + danach1012 + danach1314 + danach_15 + parks + grocery + retail + stations + workplaces + residential    | IdLandkreis + Meldedatum + stateweek  +0, Panel[Panel$Meldedatum>"2020-08-09" & Panel$Meldedatum<"2020-11-09",], cluster= ~IdLandkreis))
coefficient <- reg1$coefficients[c(1:7,9:13)]
st_error <- reg1$se[c(1:7,9:13)]*1.96
timing <- c(" [1,3]", " [4,6]", " [7,9]", "[10,12]", "[13,15]","[16,18]", "[19,21]", " [-3,-1]", "  [-6,-4]", "   [-9,-7]", "   [-12,-10]", "    [-14,-13]")
data <- as.data.frame(cbind(coefficient, st_error, timing))
data[13,] <- c(0,0," [0]")
data$coefficient <- as.numeric(data$coefficient)
data$st_error <- as.numeric(data$st_error)

# Figure A12: Left Bottom Plot
ggplot(data, aes(x=timing)) + geom_ribbon(aes(ymin=coefficient-st_error, ymax=coefficient+st_error), alpha=0.2, fill="blue", group=1) + geom_ribbon(aes(ymin=coefficient-st_error/1.959964*1.64, ymax=coefficient+st_error/1.959964*1.64), alpha=0.35, fill="blue", group=1) + geom_point(aes(y=coefficient), col="navyblue", size=2) + geom_line(aes(y=coefficient), col="navyblue", size=0.5, group=1) + theme_classic() + geom_hline(yintercept=0, linetype="dashed") + geom_vline(xintercept=6, linetype="dashed") + labs(y="Daily Cases per 100,000", x="Days") + ylim(-0.003,0.006)

########################## Regression (Match above 15%) ######################
Panel[,74:95] <- 0
Panel$Spiel_pro_Einwohner <- Panel$Zuschauer_15/Panel$Einwohner*100000
#Panel$Spiel_pro_Einwohner <- scale(Panel$Spiel_pro_Einwohner)
for (i in 1:22){
  a <- i
  b <- 73+i
  Panel[,b] <- dplyr::lag(Panel$Spiel_pro_Einwohner, a)
  Panel$lag_Kreis <- dplyr::lag(Panel$IdLandkreis, a)
  Panel[,b][Panel$lag_Kreis!=Panel$IdLandkreis] <- 0
  Panel[,b][is.na(Panel[,b])] <- 0
}
Panel[,97:111] <- 0
for (i in 1:15){
  a <- i
  b <- 96+i
  Panel[,b] <- dplyr::lead(Panel$Spiel_pro_Einwohner, a)
  Panel$lag_Kreis <- dplyr::lead(Panel$IdLandkreis, a)
  Panel[,b][Panel$lag_Kreis!=Panel$IdLandkreis] <- 0
  Panel[,b][is.na(Panel[,b])] <- 0
}
Panel$Faelle_pro_Einwohner <- Panel$Faelle/as.numeric(Panel$Einwohner)*100000
Panel$vorher_22[is.na(Panel$vorher_22)] <- 0
Panel$danach_15[is.na(Panel$danach_15)] <- 0
for (i in unique(Panel$IdLandkreis)){
  a <- Panel[Panel$IdLandkreis==i,]
  a$vorher_22 <- cumsum(a$vorher_22)
  Panel$vorher_22[Panel$IdLandkreis==i] <- a$vorher_22
}
for (i in unique(Panel$IdLandkreis)){
  a <- Panel[Panel$IdLandkreis==i,]
  a$danach_15 <- rev(cumsum(rev(a$danach_15)))
  Panel$danach_15[Panel$IdLandkreis==i] <- a$danach_15
}
# Binned Results
Panel$vorher0103 <- Panel$vorher_01+Panel$vorher_02+Panel$vorher_03
Panel$vorher0406 <- Panel$vorher_04+Panel$vorher_05+Panel$vorher_06
Panel$vorher0709 <- Panel$vorher_07+Panel$vorher_08+Panel$vorher_09
Panel$vorher1012 <- Panel$vorher_10+Panel$vorher_11+Panel$vorher_12
Panel$vorher1315 <- Panel$vorher_13+Panel$vorher_14+Panel$vorher_15
Panel$vorher1618 <- Panel$vorher_16+Panel$vorher_17+Panel$vorher_18
Panel$vorher1921 <- Panel$vorher_19+Panel$vorher_20+Panel$vorher_21
Panel$danach0103 <- Panel$danach_01+Panel$danach_02+Panel$danach_03
Panel$danach0406 <- Panel$danach_04+Panel$danach_05+Panel$danach_06
Panel$danach0709 <- Panel$danach_07+Panel$danach_08+Panel$danach_09
Panel$danach1012 <- Panel$danach_10+Panel$danach_11+Panel$danach_12
Panel$danach1314 <- Panel$danach_13+Panel$danach_14
Panel$stateweek <- paste(Panel$state, Panel$week)
reg1 <- summary(feols(Faelle_pro_Einwohner ~ vorher0103 + vorher0406 + vorher0709 + vorher1012 + vorher1315 + vorher1618 + vorher1921 + vorher_22 +
                        danach0103 + danach0406 + danach0709 + danach1012 + danach1314 + danach_15 + parks + grocery + retail + stations + workplaces + residential    | IdLandkreis + Meldedatum + stateweek  +0, Panel[Panel$Meldedatum>"2020-08-09" & Panel$Meldedatum<"2020-11-09",], cluster= ~IdLandkreis))
coefficient <- reg1$coefficients[c(1:7,9:13)]
st_error <- reg1$se[c(1:7,9:13)]*1.96
timing <- c(" [1,3]", " [4,6]", " [7,9]", "[10,12]", "[13,15]","[16,18]", "[19,21]", " [-3,-1]", "  [-6,-4]", "   [-9,-7]", "   [-12,-10]", "    [-14,-13]")
data <- as.data.frame(cbind(coefficient, st_error, timing))
data[13,] <- c(0,0," [0]")
data$coefficient <- as.numeric(data$coefficient)
data$st_error <- as.numeric(data$st_error)

# Figure A12: Right Bottom Plot
ggplot(data, aes(x=timing)) + geom_ribbon(aes(ymin=coefficient-st_error, ymax=coefficient+st_error), alpha=0.2, fill="blue", group=1) + geom_ribbon(aes(ymin=coefficient-st_error/1.959964*1.64, ymax=coefficient+st_error/1.959964*1.64), alpha=0.35, fill="blue", group=1) + geom_point(aes(y=coefficient), col="navyblue", size=2) + geom_line(aes(y=coefficient), col="navyblue", size=0.5, group=1) + theme_classic() + geom_hline(yintercept=0, linetype="dashed") + geom_vline(xintercept=6, linetype="dashed") + labs(y="Daily Cases per 100,000", x="Days") + ylim(-0.003,0.006)