## Replication Figure A2

# Load Packages
library(readr)
library(readxl)
library(dplyr)
library(ggplot2)
library(lmtest)
library(stargazer)
library(sandwich)
library(lubridate)
library(AER)
library(scales)
library(pscl)
library(plm)
library(urca)
library(tseries)
library(EventStudy)
library(gridExtra)
library(mfx)
library(stringr)
library(sf)
library(fixest)

# Set Working Directory to the 'Data' Folder of the Replication Package
setwd("XXX")

# Load Data
Panel <- read_csv("Panelhet.csv")
Panel <- as.data.frame(Panel[,-1])
Spiele_4 <- read_xlsx("Spiele.xlsx")
Stadien <- read_xlsx("Stadien.xlsx")
Auspendler <- read_excel("Auspendler.xlsx", sheet="Auspendler")
Einpendler <- read_excel("Auspendler.xlsx", sheet="Einpendler")
Einwohnerzahlen <- read_excel("Einwohnerzahlen.xlsx")

for (i in 1:nrow(Auspendler)){
  Auspendler$IdLandkreis[i] <- ifelse(is.na(Auspendler$IdLandkreis[i]), dplyr::lag(Auspendler$IdLandkreis)[i], Auspendler$IdLandkreis[i])
}
for (i in 1:nrow(Einpendler)){
  Einpendler$IdLandkreis[i] <- ifelse(is.na(Einpendler$IdLandkreis[i]), dplyr::lag(Einpendler$IdLandkreis)[i], Einpendler$IdLandkreis[i])
}
Auspendler <- dplyr::select(Auspendler, IdLandkreis, IdLandkreis_Pendel, Insgesamt)
Einpendler <- dplyr::select(Einpendler, IdLandkreis, IdLandkreis_Pendel, Insgesamt)
Auspendler$Auspendler <- Auspendler$Insgesamt
Auspendler$Insgesamt <- NULL
Einpendler$Einpendler <- Einpendler$Insgesamt
Einpendler$Insgesamt <- NULL
Pendler <- full_join(Einpendler, Auspendler, by = c("IdLandkreis", "IdLandkreis_Pendel"))
Pendler$Einpendler <- as.numeric(Pendler$Einpendler)
Pendler$Auspendler <- as.numeric(Pendler$Auspendler)
Pendler$Insgesamt <- ifelse(is.na(Pendler$Auspendler), Pendler$Einpendler, ifelse(is.na(Pendler$Einpendler), NA, Pendler$Einpendler+Pendler$Auspendler))
Pendler <- group_by(Pendler, IdLandkreis, IdLandkreis_Pendel)
Pendler <- left_join(Pendler, dplyr::select(Einwohnerzahlen, Kreis, Einwohner), by = c("IdLandkreis_Pendel" = "Kreis"))
Pendler$Einwohner_Pendler <- Pendler$Einwohner
Pendler$Einwohner <- NULL
Pendler <- left_join(Pendler, dplyr::select(Einwohnerzahlen, Kreis, Einwohner), by = c("IdLandkreis" = "Kreis"))
Pendler <- Pendler[Pendler$IdLandkreis %in% Panel$IdLandkreis,]
Pendler <- Pendler[Pendler$IdLandkreis_Pendel %in% Panel$IdLandkreis,]
Pendler$Exposure <- Pendler$Insgesamt/as.numeric(Pendler$Einwohner)
Panel$Spiel <- NULL
Panel$Zuschauer <- NULL
Spiele_4$Spiel <- 1
Panel <- left_join(Panel, summarize(group_by(dplyr::select(filter(left_join(Spiele_4, Stadien, by = c("Stadion" = "Club")), Zuschauer>0), Heimkreis, Datum, Zuschauer, Spiel), Heimkreis, Datum), Spiel=sum(Spiel), Zuschauer=sum(Zuschauer)), by = c("Meldedatum" = "Datum", "IdLandkreis" = "Heimkreis"))
Panel$Spiel[is.na(Panel$Spiel)] <- 0
Panel$Zuschauer[is.na(Panel$Zuschauer)] <- 0
Panel$Spiel_pro_Einwohner <- Panel$Spiel/Panel$Einwohner*100000
Panel$Spiel_pro_Einwohner[is.na(Panel$Spiel_pro_Einwohner)] <- 0
Panel$Neighbor <- 0
for (i in 1:nrow(Panel)){
  a <- Pendler[Pendler$IdLandkreis==Panel$IdLandkreis[i],]
  a <- left_join(a, dplyr::select(Panel[Panel$Meldedatum==Panel$Meldedatum[i],], IdLandkreis, Spiel_pro_Einwohner), by = c("IdLandkreis_Pendel" = "IdLandkreis"))
  b <- sum(a$Spiel_pro_Einwohner*a$Exposure, na.rm=TRUE)
  Panel$Neighbor[i] <- b
}
Panel$Spiel_pro_Einwohner <- Panel$Neighbor
Panel[,74:95] <- 0
for (i in 1:22){
  a <- i
  b <- 73+i
  Panel[,b] <- dplyr::lag(Panel$Spiel_pro_Einwohner, a)
  Panel$lag_Kreis <- dplyr::lag(Panel$IdLandkreis, a)
  Panel[,b][Panel$lag_Kreis!=Panel$IdLandkreis] <- 0
  Panel[,b][is.na(Panel[,b])] <- 0
}
Panel[,97:111] <- 0
for (i in 1:15){
  a <- i
  b <- 96+i
  Panel[,b] <- dplyr::lead(Panel$Spiel_pro_Einwohner, a)
  Panel$lag_Kreis <- dplyr::lead(Panel$IdLandkreis, a)
  Panel[,b][Panel$lag_Kreis!=Panel$IdLandkreis] <- 0
  Panel[,b][is.na(Panel[,b])] <- 0
}
Panel$Faelle_pro_Einwohner <- Panel$Faelle/Panel$Einwohner*100000
Panel$vorher_22[is.na(Panel$vorher_22)] <- 0
Panel$danach_15[is.na(Panel$danach_15)] <- 0
for (i in unique(Panel$IdLandkreis)){
  a <- Panel[Panel$IdLandkreis==i,]
  a$vorher_22 <- cumsum(a$vorher_22)
  Panel$vorher_22[Panel$IdLandkreis==i] <- a$vorher_22
}
for (i in unique(Panel$IdLandkreis)){
  a <- Panel[Panel$IdLandkreis==i,]
  a$danach_15 <- rev(cumsum(rev(a$danach_15)))
  Panel$danach_15[Panel$IdLandkreis==i] <- a$danach_15
}
# Binned Results
Panel$vorher0103 <- Panel$vorher_01+Panel$vorher_02+Panel$vorher_03
Panel$vorher0406 <- Panel$vorher_04+Panel$vorher_05+Panel$vorher_06
Panel$vorher0709 <- Panel$vorher_07+Panel$vorher_08+Panel$vorher_09
Panel$vorher1012 <- Panel$vorher_10+Panel$vorher_11+Panel$vorher_12
Panel$vorher1315 <- Panel$vorher_13+Panel$vorher_14+Panel$vorher_15
Panel$vorher1618 <- Panel$vorher_16+Panel$vorher_17+Panel$vorher_18
Panel$vorher1921 <- Panel$vorher_19+Panel$vorher_20+Panel$vorher_21
Panel$danach0103 <- Panel$danach_01+Panel$danach_02+Panel$danach_03
Panel$danach0406 <- Panel$danach_04+Panel$danach_05+Panel$danach_06
Panel$danach0709 <- Panel$danach_07+Panel$danach_08+Panel$danach_09
Panel$danach1012 <- Panel$danach_10+Panel$danach_11+Panel$danach_12
Panel$danach1314 <- Panel$danach_13+Panel$danach_14
Panel$stateweek <- paste(Panel$state, Panel$week)
reg1 <- summary(feols(Faelle_pro_Einwohner ~ vorher0103 + vorher0406 + vorher0709 + vorher1012 + vorher1315 + vorher1618 + vorher1921 + vorher_22 +
                        danach0103 + danach0406 + danach0709 + danach1012 + danach1314 + danach_15 + parks + grocery + retail + stations + workplaces + residential    | IdLandkreis + Meldedatum + stateweek  +0, Panel[Panel$Meldedatum>"2020-08-09" & Panel$Meldedatum<"2020-11-09",], cluster= ~IdLandkreis))
coefficient <- reg1$coefficients[c(1:7,9:13)]
st_error <- reg1$se[c(1:7,9:13)]*1.96
timing <- c(" [1,3]", " [4,6]", " [7,9]", "[10,12]", "[13,15]","[16,18]", "[19,21]", " [-3,-1]", "  [-6,-4]", "   [-9,-7]", "   [-12,-10]", "    [-14,-13]")
data <- as.data.frame(cbind(coefficient, st_error, timing))
data[13,] <- c(0,0," [0]")
data$coefficient <- as.numeric(data$coefficient)
data$st_error <- as.numeric(data$st_error)

# Figure A2: Left Plot
ggplot(data, aes(x=timing)) + geom_ribbon(aes(ymin=coefficient-st_error, ymax=coefficient+st_error), alpha=0.2, fill="blue", group=1) + geom_ribbon(aes(ymin=coefficient-st_error/1.959964*1.64, ymax=coefficient+st_error/1.959964*1.64), alpha=0.35, fill="blue", group=1) + geom_point(aes(y=coefficient), col="navyblue", size=2) + geom_line(aes(y=coefficient), col="navyblue", size=0.5, group=1) + theme_classic() + geom_hline(yintercept=0, linetype="dashed") + geom_vline(xintercept=6, linetype="dashed") + labs(y="Daily Cases per 100,000", x="Days") + ylim(-25,25)



# Load Data
Panel <- read_csv("Panelhet.csv")
Panel <- as.data.frame(Panel[,-1])
Spiele_4 <- read_xlsx("Spiele.xlsx")
Stadien <- read_xlsx("Stadien.xlsx")
Auspendler <- read_excel("Auspendler.xlsx", sheet="Auspendler")
Einpendler <- read_excel("Auspendler.xlsx", sheet="Einpendler")
Einwohnerzahlen <- read_excel("Einwohnerzahlen.xlsx")

for (i in 1:nrow(Auspendler)){
  Auspendler$IdLandkreis[i] <- ifelse(is.na(Auspendler$IdLandkreis[i]), dplyr::lag(Auspendler$IdLandkreis)[i], Auspendler$IdLandkreis[i])
}
for (i in 1:nrow(Einpendler)){
  Einpendler$IdLandkreis[i] <- ifelse(is.na(Einpendler$IdLandkreis[i]), dplyr::lag(Einpendler$IdLandkreis)[i], Einpendler$IdLandkreis[i])
}
Auspendler <- dplyr::select(Auspendler, IdLandkreis, IdLandkreis_Pendel, Insgesamt)
Einpendler <- dplyr::select(Einpendler, IdLandkreis, IdLandkreis_Pendel, Insgesamt)
Auspendler$Auspendler <- Auspendler$Insgesamt
Auspendler$Insgesamt <- NULL
Einpendler$Einpendler <- Einpendler$Insgesamt
Einpendler$Insgesamt <- NULL
Pendler <- full_join(Einpendler, Auspendler, by = c("IdLandkreis", "IdLandkreis_Pendel"))
Pendler$Einpendler <- as.numeric(Pendler$Einpendler)
Pendler$Auspendler <- as.numeric(Pendler$Auspendler)
Pendler$Insgesamt <- ifelse(is.na(Pendler$Auspendler), Pendler$Einpendler, ifelse(is.na(Pendler$Einpendler), NA, Pendler$Einpendler+Pendler$Auspendler))
Pendler <- group_by(Pendler, IdLandkreis, IdLandkreis_Pendel)
Pendler <- left_join(Pendler, dplyr::select(Einwohnerzahlen, Kreis, Einwohner), by = c("IdLandkreis_Pendel" = "Kreis"))
Pendler$Einwohner_Pendler <- Pendler$Einwohner
Pendler$Einwohner <- NULL
Pendler <- left_join(Pendler, dplyr::select(Einwohnerzahlen, Kreis, Einwohner), by = c("IdLandkreis" = "Kreis"))
Pendler <- Pendler[Pendler$IdLandkreis %in% Panel$IdLandkreis,]
Pendler <- Pendler[Pendler$IdLandkreis_Pendel %in% Panel$IdLandkreis,]
Pendler$Exposure <- Pendler$Insgesamt/as.numeric(Pendler$Einwohner)
Panel$Spiel <- NULL
Panel$Zuschauer <- NULL
Spiele_4$Spiel <- 1
Panel <- left_join(Panel, summarize(group_by(dplyr::select(filter(left_join(Spiele_4, Stadien, by = c("Stadion" = "Club")), Zuschauer>0), Heimkreis, Datum, Zuschauer, Spiel), Heimkreis, Datum), Spiel=sum(Spiel), Zuschauer=sum(Zuschauer)), by = c("Meldedatum" = "Datum", "IdLandkreis" = "Heimkreis"))
Panel$Spiel[is.na(Panel$Spiel)] <- 0
Panel$Zuschauer[is.na(Panel$Zuschauer)] <- 0
Panel$Spiel_pro_Einwohner <- Panel$Zuschauer/Panel$Einwohner*100000
Panel$Spiel_pro_Einwohner[is.na(Panel$Spiel_pro_Einwohner)] <- 0
Panel$Neighbor <- 0
for (i in 1:nrow(Panel)){
  a <- Pendler[Pendler$IdLandkreis==Panel$IdLandkreis[i],]
  a <- left_join(a, dplyr::select(Panel[Panel$Meldedatum==Panel$Meldedatum[i],], IdLandkreis, Spiel_pro_Einwohner), by = c("IdLandkreis_Pendel" = "IdLandkreis"))
  b <- sum(a$Spiel_pro_Einwohner*a$Exposure, na.rm=TRUE)
  Panel$Neighbor[i] <- b
}
Panel$Spiel_pro_Einwohner <- Panel$Neighbor
Panel[,74:95] <- 0
for (i in 1:22){
  a <- i
  b <- 73+i
  Panel[,b] <- dplyr::lag(Panel$Spiel_pro_Einwohner, a)
  Panel$lag_Kreis <- dplyr::lag(Panel$IdLandkreis, a)
  Panel[,b][Panel$lag_Kreis!=Panel$IdLandkreis] <- 0
  Panel[,b][is.na(Panel[,b])] <- 0
}
Panel[,97:111] <- 0
for (i in 1:15){
  a <- i
  b <- 96+i
  Panel[,b] <- dplyr::lead(Panel$Spiel_pro_Einwohner, a)
  Panel$lag_Kreis <- dplyr::lead(Panel$IdLandkreis, a)
  Panel[,b][Panel$lag_Kreis!=Panel$IdLandkreis] <- 0
  Panel[,b][is.na(Panel[,b])] <- 0
}
Panel$Faelle_pro_Einwohner <- Panel$Faelle/Panel$Einwohner*100000
Panel$vorher_22[is.na(Panel$vorher_22)] <- 0
Panel$danach_15[is.na(Panel$danach_15)] <- 0
for (i in unique(Panel$IdLandkreis)){
  a <- Panel[Panel$IdLandkreis==i,]
  a$vorher_22 <- cumsum(a$vorher_22)
  Panel$vorher_22[Panel$IdLandkreis==i] <- a$vorher_22
}
for (i in unique(Panel$IdLandkreis)){
  a <- Panel[Panel$IdLandkreis==i,]
  a$danach_15 <- rev(cumsum(rev(a$danach_15)))
  Panel$danach_15[Panel$IdLandkreis==i] <- a$danach_15
}
# Binned Results
Panel$vorher0103 <- Panel$vorher_01+Panel$vorher_02+Panel$vorher_03
Panel$vorher0406 <- Panel$vorher_04+Panel$vorher_05+Panel$vorher_06
Panel$vorher0709 <- Panel$vorher_07+Panel$vorher_08+Panel$vorher_09
Panel$vorher1012 <- Panel$vorher_10+Panel$vorher_11+Panel$vorher_12
Panel$vorher1315 <- Panel$vorher_13+Panel$vorher_14+Panel$vorher_15
Panel$vorher1618 <- Panel$vorher_16+Panel$vorher_17+Panel$vorher_18
Panel$vorher1921 <- Panel$vorher_19+Panel$vorher_20+Panel$vorher_21
Panel$danach0103 <- Panel$danach_01+Panel$danach_02+Panel$danach_03
Panel$danach0406 <- Panel$danach_04+Panel$danach_05+Panel$danach_06
Panel$danach0709 <- Panel$danach_07+Panel$danach_08+Panel$danach_09
Panel$danach1012 <- Panel$danach_10+Panel$danach_11+Panel$danach_12
Panel$danach1314 <- Panel$danach_13+Panel$danach_14
Panel$stateweek <- paste(Panel$state, Panel$week)
reg1 <- summary(feols(Faelle_pro_Einwohner ~ vorher0103 + vorher0406 + vorher0709 + vorher1012 + vorher1315 + vorher1618 + vorher1921 + vorher_22 +
                        danach0103 + danach0406 + danach0709 + danach1012 + danach1314 + danach_15 + parks + grocery + retail + stations + workplaces + residential    | IdLandkreis + Meldedatum + stateweek  +0, Panel[Panel$Meldedatum>"2020-08-09" & Panel$Meldedatum<"2020-11-09",], cluster= ~IdLandkreis))
coefficient <- reg1$coefficients[c(1:7,9:13)]
st_error <- reg1$se[c(1:7,9:13)]*1.96
timing <- c(" [1,3]", " [4,6]", " [7,9]", "[10,12]", "[13,15]","[16,18]", "[19,21]", " [-3,-1]", "  [-6,-4]", "   [-9,-7]", "   [-12,-10]", "    [-14,-13]")
data <- as.data.frame(cbind(coefficient, st_error, timing))
data[13,] <- c(0,0," [0]")
data$coefficient <- as.numeric(data$coefficient)
data$st_error <- as.numeric(data$st_error)

# Figure A2: Right Plot
ggplot(data, aes(x=timing)) + geom_ribbon(aes(ymin=coefficient-st_error, ymax=coefficient+st_error), alpha=0.2, fill="blue", group=1) + geom_ribbon(aes(ymin=coefficient-st_error/1.959964*1.64, ymax=coefficient+st_error/1.959964*1.64), alpha=0.35, fill="blue", group=1) + geom_point(aes(y=coefficient), col="navyblue", size=2) + geom_line(aes(y=coefficient), col="navyblue", size=0.5, group=1) + theme_classic() + geom_hline(yintercept=0, linetype="dashed") + geom_vline(xintercept=6, linetype="dashed") + labs(y="Daily Cases per 100,000", x="Days") + ylim(-0.02,0.02)
