## Replication Figure A23 and Table A3

# Load Packages
library(readr)
library(readxl)
library(dplyr)
library(ggplot2)
library(lmtest)
library(stargazer)
library(sandwich)
library(lubridate)
library(AER)
library(scales)
library(pscl)
library(plm)
library(urca)
library(tseries)
library(EventStudy)
library(gridExtra)
library(mfx)
library(stringr)
library(sf)
library(fixest)

# Set Working Directory to the 'Data' Folder of the Replication Package
setwd("XXX")

# Load Data
Panel <- read_csv("Panel.csv")
Panel <- Panel[,-1]
Panel <- data.frame(Panel)

Panel <- Panel %>% group_by(IdLandkreis) %>% arrange(as.Date(Meldedatum)) %>% mutate(Spiele_cumsum = cumsum(as.numeric(Spiel)))
Panel$treated <- ifelse(Panel$Spiele_cumsum>0, 1, 0)
Panel <- Panel[order(Panel$IdLandkreis, Panel$Meldedatum),]
Panel$late <- ifelse(dplyr::lag(Panel$treated, 10)==1, 1, 0)
Panel$Faelle_pro_Einwohner <- Panel$Faelle/Panel$Einwohner*100000
Panel$Todesfall_pro_Einwohner <- Panel$Todesfall/Panel$Einwohner*100000
Panel$stateweek <- paste(Panel$IdBundesland, Panel$week)
Panel$NUTS2 <- NULL
Panel$tests <- NULL
Panel$a <- NULL
Panel$Inzidenz_Tode <- NULL
Panel$Inzidenz_Faelle <- NULL
Panel$Durchschnittsalter_gesamt <- NULL
Panel$treated2 <- ifelse(Panel$treated == 1 & dplyr::lag(Panel$treated) == 0 & Panel$IdLandkreis == dplyr::lag(Panel$IdLandkreis), 1, 0)

# Table A3
reg1 <- feols(Faelle_pro_Einwohner ~ treated + parks + grocery + retail + stations + workplaces + residential | IdLandkreis + Meldedatum + stateweek, Panel[Panel$Meldedatum>"2020-08-09" & Panel$Meldedatum<"2020-11-09",])
reg1 <- feols(Faelle_pro_Einwohner ~ treated + late + parks + grocery + retail + stations + workplaces + residential | IdLandkreis + Meldedatum + stateweek, Panel[Panel$Meldedatum>"2020-08-09" & Panel$Meldedatum<"2020-11-09",])
reg1 <- feols(Todesfall_pro_Einwohner ~ treated + parks + grocery + retail + stations + workplaces + residential | IdLandkreis + Meldedatum + stateweek, Panel[Panel$Meldedatum>"2020-08-09" & Panel$Meldedatum<"2020-11-09",])
reg1 <- feols(Todesfall_pro_Einwohner ~ treated + late + parks + grocery + retail + stations + workplaces + residential | IdLandkreis + Meldedatum + stateweek, Panel[Panel$Meldedatum>"2020-08-09" & Panel$Meldedatum<"2020-11-09",])

Panel <- Panel[order(Panel$IdLandkreis, Panel$Meldedatum),]
Panel$vorher_01 <- ifelse(Panel$IdLandkreis==dplyr::lag(Panel$IdLandkreis,1) & dplyr::lag(Panel$treated2,1)==1 , 1, 0)
Panel$vorher_02 <- ifelse(Panel$IdLandkreis==dplyr::lag(Panel$IdLandkreis,2) & dplyr::lag(Panel$treated2,2)==1 , 1, 0)
Panel$vorher_03 <- ifelse(Panel$IdLandkreis==dplyr::lag(Panel$IdLandkreis,3) & dplyr::lag(Panel$treated2,3)==1 , 1, 0)
Panel$vorher_04 <- ifelse(Panel$IdLandkreis==dplyr::lag(Panel$IdLandkreis,4) & dplyr::lag(Panel$treated2,4)==1 , 1, 0)
Panel$vorher_05 <- ifelse(Panel$IdLandkreis==dplyr::lag(Panel$IdLandkreis,5) & dplyr::lag(Panel$treated2,5)==1 , 1, 0)
Panel$vorher_06 <- ifelse(Panel$IdLandkreis==dplyr::lag(Panel$IdLandkreis,6) & dplyr::lag(Panel$treated2,6)==1 , 1, 0)
Panel$vorher_07 <- ifelse(Panel$IdLandkreis==dplyr::lag(Panel$IdLandkreis,7) & dplyr::lag(Panel$treated2,7)==1 , 1, 0)
Panel$vorher_08 <- ifelse(Panel$IdLandkreis==dplyr::lag(Panel$IdLandkreis,8) & dplyr::lag(Panel$treated2,8)==1 , 1, 0)
Panel$vorher_09 <- ifelse(Panel$IdLandkreis==dplyr::lag(Panel$IdLandkreis,9) & dplyr::lag(Panel$treated2,9)==1 , 1, 0)
Panel$vorher_10 <- ifelse(Panel$IdLandkreis==dplyr::lag(Panel$IdLandkreis,10) & dplyr::lag(Panel$treated2,10)==1 , 1, 0)
Panel$vorher_11 <- ifelse(Panel$IdLandkreis==dplyr::lag(Panel$IdLandkreis,11) & dplyr::lag(Panel$treated2,11)==1 , 1, 0)
Panel$vorher_12 <- ifelse(Panel$IdLandkreis==dplyr::lag(Panel$IdLandkreis,12) & dplyr::lag(Panel$treated2,12)==1 , 1, 0)
Panel$vorher_13 <- ifelse(Panel$IdLandkreis==dplyr::lag(Panel$IdLandkreis,13) & dplyr::lag(Panel$treated2,13)==1 , 1, 0)
Panel$vorher_14 <- ifelse(Panel$IdLandkreis==dplyr::lag(Panel$IdLandkreis,14) & dplyr::lag(Panel$treated2,14)==1, 1, 0)
Panel$vorher_15 <- ifelse(Panel$IdLandkreis==dplyr::lag(Panel$IdLandkreis,15) & dplyr::lag(Panel$treated2,15)==1, 1, 0)
Panel$vorher_16 <- ifelse(Panel$IdLandkreis==dplyr::lag(Panel$IdLandkreis,16) & dplyr::lag(Panel$treated2,16)==1 , 1, 0)
Panel$vorher_17 <- ifelse(Panel$IdLandkreis==dplyr::lag(Panel$IdLandkreis,17) & dplyr::lag(Panel$treated2,17)==1 , 1, 0)
Panel$vorher_18 <- ifelse(Panel$IdLandkreis==dplyr::lag(Panel$IdLandkreis,18) & dplyr::lag(Panel$treated2,18)==1 , 1, 0)
Panel$vorher_19 <- ifelse(Panel$IdLandkreis==dplyr::lag(Panel$IdLandkreis,19) & dplyr::lag(Panel$treated2,19)==1 , 1, 0)
Panel$vorher_20 <- ifelse(Panel$IdLandkreis==dplyr::lag(Panel$IdLandkreis,20) & dplyr::lag(Panel$treated2,20)==1 , 1, 0)
Panel$vorher_21 <- ifelse(Panel$IdLandkreis==dplyr::lag(Panel$IdLandkreis,21) & dplyr::lag(Panel$treated2,21)==1 , 1, 0)
Panel$vorher_22 <- ifelse(Panel$IdLandkreis==dplyr::lag(Panel$IdLandkreis,22) & dplyr::lag(Panel$treated2,22)==1 , 1, 0)
Panel$vorher_23 <- ifelse(Panel$IdLandkreis==dplyr::lag(Panel$IdLandkreis,23) & dplyr::lag(Panel$treated2,23)==1 , 1, 0)
Panel$vorher_24 <- ifelse(Panel$IdLandkreis==dplyr::lag(Panel$IdLandkreis,24) & dplyr::lag(Panel$treated2,24)==1 , 1, 0)
Panel$vorher_25 <- ifelse(Panel$IdLandkreis==dplyr::lag(Panel$IdLandkreis,25) & dplyr::lag(Panel$treated2,25)==1 , 1, 0)
Panel$vorher_26 <- ifelse(Panel$IdLandkreis==dplyr::lag(Panel$IdLandkreis,26) & dplyr::lag(Panel$treated2,26)==1 , 1, 0)
Panel$vorher_27 <- ifelse(Panel$IdLandkreis==dplyr::lag(Panel$IdLandkreis,27) & dplyr::lag(Panel$treated2,27)==1 , 1, 0)
Panel$vorher_28 <- ifelse(Panel$IdLandkreis==dplyr::lag(Panel$IdLandkreis,28) & dplyr::lag(Panel$treated2,28)==1 , 1, 0)
Panel$vorher_29 <- ifelse(Panel$IdLandkreis==dplyr::lag(Panel$IdLandkreis,29) & dplyr::lag(Panel$treated2,29)==1 , 1, 0)
Panel$vorher_30 <- ifelse(Panel$IdLandkreis==dplyr::lag(Panel$IdLandkreis,30) & dplyr::lag(Panel$treated2,30)==1 , 1, 0)
Panel$vorher_31 <- ifelse(Panel$IdLandkreis==dplyr::lag(Panel$IdLandkreis,31) & dplyr::lag(Panel$treated2,31)==1 , 1, 0)
Panel$vorher_32 <- ifelse(Panel$IdLandkreis==dplyr::lag(Panel$IdLandkreis,32) & dplyr::lag(Panel$treated2,32)==1 , 1, 0)
Panel$vorher_33 <- ifelse(Panel$IdLandkreis==dplyr::lag(Panel$IdLandkreis,33) & dplyr::lag(Panel$treated2,33)==1 , 1, 0)
Panel$vorher_34 <- ifelse(Panel$IdLandkreis==dplyr::lag(Panel$IdLandkreis,34) & dplyr::lag(Panel$treated2,34)==1 , 1, 0)
Panel$vorher_35 <- ifelse(Panel$IdLandkreis==dplyr::lag(Panel$IdLandkreis,35) & dplyr::lag(Panel$treated2,35)==1 , 1, 0)
Panel$vorher_36 <- ifelse(Panel$IdLandkreis==dplyr::lag(Panel$IdLandkreis,36) & dplyr::lag(Panel$treated2,36)==1 , 1, 0)
Panel$vorher_37 <- ifelse(Panel$IdLandkreis==dplyr::lag(Panel$IdLandkreis,37) & dplyr::lag(Panel$treated2,37)==1 , 1, 0)
Panel$vorher_38 <- ifelse(Panel$IdLandkreis==dplyr::lag(Panel$IdLandkreis,38) & dplyr::lag(Panel$treated2,38)==1 , 1, 0)
Panel$vorher_39 <- ifelse(Panel$IdLandkreis==dplyr::lag(Panel$IdLandkreis,39) & dplyr::lag(Panel$treated2,39)==1 , 1, 0)
Panel$vorher_40 <- ifelse(Panel$IdLandkreis==dplyr::lag(Panel$IdLandkreis,40) & dplyr::lag(Panel$treated2,40)==1 , 1, 0)
Panel$vorher_41 <- ifelse(Panel$IdLandkreis==dplyr::lag(Panel$IdLandkreis,41) & dplyr::lag(Panel$treated2,41)==1 , 1, 0)
Panel$vorher_42 <- ifelse(Panel$IdLandkreis==dplyr::lag(Panel$IdLandkreis,42) & dplyr::lag(Panel$treated2,42)==1 , 1, 0)
Panel$vorher_43 <- ifelse(Panel$IdLandkreis==dplyr::lag(Panel$IdLandkreis,43) & dplyr::lag(Panel$treated2,43)==1 , 1, 0)
Panel[,76:118][is.na(Panel[,76:118])] <- 0
Panel <- Panel %>% group_by(IdLandkreis) %>% arrange(as.Date(Meldedatum)) %>% mutate(vorher_43 = cumsum(as.numeric(vorher_43)))
Panel$vorher_43 <- ifelse(Panel$vorher_43>0, 1, 0)
Panel <- Panel[order(Panel$IdLandkreis, Panel$Meldedatum),]
Panel$danach_01 <- ifelse(Panel$IdLandkreis==dplyr::lead(Panel$IdLandkreis,1) & dplyr::lead(Panel$treated2,1)==1 , 1, 0)
Panel$danach_02 <- ifelse(Panel$IdLandkreis==dplyr::lead(Panel$IdLandkreis,2) & dplyr::lead(Panel$treated2,2)==1 , 1, 0)
Panel$danach_03 <- ifelse(Panel$IdLandkreis==dplyr::lead(Panel$IdLandkreis,3) & dplyr::lead(Panel$treated2,3)==1 , 1, 0)
Panel$danach_04 <- ifelse(Panel$IdLandkreis==dplyr::lead(Panel$IdLandkreis,4) & dplyr::lead(Panel$treated2,4)==1 , 1, 0)
Panel$danach_05 <- ifelse(Panel$IdLandkreis==dplyr::lead(Panel$IdLandkreis,5) & dplyr::lead(Panel$treated2,5)==1 , 1, 0)
Panel$danach_06 <- ifelse(Panel$IdLandkreis==dplyr::lead(Panel$IdLandkreis,6) & dplyr::lead(Panel$treated2,6)==1 , 1, 0)
Panel$danach_07 <- ifelse(Panel$IdLandkreis==dplyr::lead(Panel$IdLandkreis,7) & dplyr::lead(Panel$treated2,7)==1 , 1, 0)
Panel$danach_08 <- ifelse(Panel$IdLandkreis==dplyr::lead(Panel$IdLandkreis,8) & dplyr::lead(Panel$treated2,8)==1 , 1, 0)
Panel$danach_09 <- ifelse(Panel$IdLandkreis==dplyr::lead(Panel$IdLandkreis,9) & dplyr::lead(Panel$treated2,9)==1 , 1, 0)
Panel$danach_10 <- ifelse(Panel$IdLandkreis==dplyr::lead(Panel$IdLandkreis,10) & dplyr::lead(Panel$treated2,10)==1 , 1, 0)
Panel$danach_11 <- ifelse(Panel$IdLandkreis==dplyr::lead(Panel$IdLandkreis,11) & dplyr::lead(Panel$treated2,11)==1 , 1, 0)
Panel$danach_12 <- ifelse(Panel$IdLandkreis==dplyr::lead(Panel$IdLandkreis,12) & dplyr::lead(Panel$treated2,12)==1 , 1, 0)
Panel$danach_13 <- ifelse(Panel$IdLandkreis==dplyr::lead(Panel$IdLandkreis,13) & dplyr::lead(Panel$treated2,13)==1 , 1, 0)
Panel$danach_14 <- ifelse(Panel$IdLandkreis==dplyr::lead(Panel$IdLandkreis,14) & dplyr::lead(Panel$treated2,14)==1 , 1, 0)
Panel$danach_15 <- ifelse(Panel$IdLandkreis==dplyr::lead(Panel$IdLandkreis,15) & dplyr::lead(Panel$treated2,15)==1 , 1, 0)
Panel[,119:133][is.na(Panel[,119:133])] <- 0
Panel$a <- ifelse(Panel$IdLandkreis %in% Panel$IdLandkreis[Panel$treated2==1], 1, 0)
Panel$danach_15 <- Panel$a - Panel$treated2 - Panel$vorher_01 - Panel$vorher_02 - Panel$vorher_03 - Panel$vorher_04 - Panel$vorher_05 - Panel$vorher_06 - Panel$vorher_07 -
  Panel$vorher_08 - Panel$vorher_09 - Panel$vorher_10 - Panel$vorher_11 - Panel$vorher_12 - Panel$vorher_13 - Panel$vorher_14 - Panel$vorher_15 - Panel$vorher_16 -
  Panel$vorher_17 - Panel$vorher_18 - Panel$vorher_19 - Panel$vorher_20 - Panel$vorher_21 - Panel$vorher_22 - Panel$vorher_23 - Panel$vorher_24 - Panel$vorher_25 -
  Panel$vorher_26 - Panel$vorher_27 - Panel$vorher_28 - Panel$vorher_29 - Panel$danach_01 - Panel$danach_02 - Panel$danach_03 - Panel$danach_04 - Panel$danach_05 -
  Panel$danach_06 - Panel$danach_07 - Panel$danach_07 - Panel$danach_08 - Panel$danach_09 - Panel$danach_10 - Panel$danach_11 - Panel$danach_12 - Panel$danach_13 - Panel$danach_14

# Binned Results
Panel$vorher0103 <- Panel$vorher_01+Panel$vorher_02+Panel$vorher_03
Panel$vorher0406 <- Panel$vorher_04+Panel$vorher_05+Panel$vorher_06
Panel$vorher0709 <- Panel$vorher_07+Panel$vorher_08+Panel$vorher_09
Panel$vorher1012 <- Panel$vorher_10+Panel$vorher_11+Panel$vorher_12
Panel$vorher1315 <- Panel$vorher_13+Panel$vorher_14+Panel$vorher_15
Panel$vorher1618 <- Panel$vorher_16+Panel$vorher_17+Panel$vorher_18
Panel$vorher1921 <- Panel$vorher_19+Panel$vorher_20+Panel$vorher_21
Panel$vorher2224 <- Panel$vorher_22+Panel$vorher_23+Panel$vorher_24
Panel$vorher2527 <- Panel$vorher_25+Panel$vorher_26+Panel$vorher_27
Panel$vorher2830 <- Panel$vorher_28+Panel$vorher_29+Panel$vorher_30
Panel$vorher3133 <- Panel$vorher_31+Panel$vorher_32+Panel$vorher_33
Panel$vorher3436 <- Panel$vorher_34+Panel$vorher_35+Panel$vorher_36
Panel$vorher3739 <- Panel$vorher_37+Panel$vorher_38+Panel$vorher_39
Panel$vorher_4042 <- Panel$vorher_40+Panel$vorher_41+Panel$vorher_42
Panel$danach0103 <- Panel$danach_01+Panel$danach_02+Panel$danach_03
Panel$danach0406 <- Panel$danach_04+Panel$danach_05+Panel$danach_06
Panel$danach0709 <- Panel$danach_07+Panel$danach_08+Panel$danach_09
Panel$danach1012 <- Panel$danach_10+Panel$danach_11+Panel$danach_12
Panel$danach1314 <- Panel$danach_13+Panel$danach_14
Panel$stateweek <- paste(Panel$IdBundesland, Panel$week)

# Fig A23
reg1 <- summary(feols(Faelle_pro_Einwohner ~ vorher0103 + vorher0406 + vorher0709 + vorher1012 + vorher1315 + vorher1618 + vorher1921 + vorher2224 + vorher2527 +
                        vorher2830 + vorher3133 + vorher3436 + vorher3739 + vorher_4042 + vorher_43 +
                        danach0103 + danach0406 + danach0709 + danach1012 + danach1314 + danach_15 + parks + grocery + retail + stations + workplaces + residential    | IdLandkreis + Meldedatum + stateweek  +0, Panel[Panel$Meldedatum>"2020-08-09" & Panel$Meldedatum<"2020-11-09",], cluster= ~IdLandkreis))
coefficient <- reg1$coefficients[c(1:14,16:20)]
st_error <- reg1$se[c(1:14,16:20)]*1.96
timing <- c(" [1,3]", " [4,6]", " [7,9]", "[10,12]", "[13,15]","[16,18]", "[19,21]", "[22,24]", "[25,27]", "[28,30]", "[31,33]", "[34,36]", "[37,39]", "[40,42]", " [-3,-1]", "  [-6,-4]", "   [-9,-7]", "   [-12,-10]", "    [-14,-13]")
data <- as.data.frame(cbind(coefficient, st_error, timing))
data[20,] <- c(0,0," [0]")
data$coefficient <- as.numeric(data$coefficient)
data$st_error <- as.numeric(data$st_error)
ggplot(data, aes(x=timing)) + geom_ribbon(aes(ymin=coefficient-st_error, ymax=coefficient+st_error), alpha=0.2, fill="blue", group=1) + geom_ribbon(aes(ymin=coefficient-st_error/1.959964*1.64, ymax=coefficient+st_error/1.959964*1.64), alpha=0.35, fill="blue", group=1) + geom_point(aes(y=coefficient), col="navyblue", size=2) + geom_line(aes(y=coefficient), col="navyblue", size=0.5, group=1) + theme_classic() + geom_hline(yintercept=0, linetype="dashed") + geom_vline(xintercept=6, linetype="dashed") + labs(y="Daily Cases per 100,000", x="Days") + ylim(-2.5,5.5)
