## Replication Figure A3 and Figure A21

# Load Packages
library(readr)
library(readxl)
library(dplyr)
library(ggplot2)
library(lmtest)
library(stargazer)
library(sandwich)
library(lubridate)
library(AER)
library(scales)
library(pscl)
library(plm)
library(urca)
library(tseries)
library(EventStudy)
library(gridExtra)
library(mfx)
library(stringr)
library(sf)
library(fixest)

# Set Working Directory to the 'Data' Folder of the Replication Package
setwd("XXX")

# Load Data
Panel <- read_csv("Panel.csv")
Panel <- Panel[,-1]
Panel <- data.frame(Panel)
NPI <- read_csv("NPI.csv")

Panel <- left_join(Panel, NPI, by = c("IdLandkreis" = "ags5", "Meldedatum" = "Datum"))

# Binned Results
Panel$vorher0103 <- Panel$vorher_01+Panel$vorher_02+Panel$vorher_03
Panel$vorher0406 <- Panel$vorher_04+Panel$vorher_05+Panel$vorher_06
Panel$vorher0709 <- Panel$vorher_07+Panel$vorher_08+Panel$vorher_09
Panel$vorher1012 <- Panel$vorher_10+Panel$vorher_11+Panel$vorher_12
Panel$vorher1315 <- Panel$vorher_13+Panel$vorher_14+Panel$vorher_15
Panel$vorher1618 <- Panel$vorher_16+Panel$vorher_17+Panel$vorher_18
Panel$vorher1921 <- Panel$vorher_19+Panel$vorher_20+Panel$vorher_21
#Panel$vorher2224 <- Panel$vorher_22+Panel$vorher_23+Panel$vorher_24
#Panel$vorher2528 <- Panel$vorher_25+Panel$vorher_26+Panel$vorher_27+Panel$vorher_28
Panel$danach0103 <- Panel$danach_01+Panel$danach_02+Panel$danach_03
Panel$danach0406 <- Panel$danach_04+Panel$danach_05+Panel$danach_06
Panel$danach0709 <- Panel$danach_07+Panel$danach_08+Panel$danach_09
Panel$danach1012 <- Panel$danach_10+Panel$danach_11+Panel$danach_12
Panel$danach1314 <- Panel$danach_13+Panel$danach_14
Panel$stateweek <- paste(Panel$IdBundesland, Panel$week)

# Binned
reg1 <- summary(feols(Faelle_pro_Einwohner ~ vorher0103 + vorher0406 + vorher0709 + vorher1012 + vorher1315 + vorher1618 + vorher1921 + vorher_22 +
                        danach0103 + danach0406 + danach0709 + danach1012 + danach1314 + danach_15 + parks + grocery + retail + stations + workplaces + residential +
                        m1 + m2 + m3 + m4 + m5 + m6 + m7 + m8 + m9 + m10 + m11 + m12 + m13 + m14 + m15 + m16 + m17 + m18 + m19 + m20 + m21 + m22 + m23| IdLandkreis + Meldedatum + stateweek  +0, Panel[Panel$Meldedatum>"2020-08-09" & Panel$Meldedatum<"2020-11-09",], cluster= ~IdLandkreis))
coefficient <- reg1$coefficients[c(1:7,9:13)]
st_error <- reg1$se[c(1:7,9:13)]*1.96
timing <- c(" [1,3]", " [4,6]", " [7,9]", "[10,12]", "[13,15]","[16,18]", "[19,21]", " [-3,-1]", "  [-6,-4]", "   [-9,-7]", "   [-12,-10]", "    [-14,-13]")
data <- as.data.frame(cbind(coefficient, st_error, timing))
data[13,] <- c(0,0," [0]")
data$coefficient <- as.numeric(data$coefficient)
data$st_error <- as.numeric(data$st_error)
ggplot(data, aes(x=timing)) + geom_ribbon(aes(ymin=coefficient-st_error, ymax=coefficient+st_error), alpha=0.2, fill="blue", group=1) + geom_ribbon(aes(ymin=coefficient-st_error/1.959964*1.64, ymax=coefficient+st_error/1.959964*1.64), alpha=0.35, fill="blue", group=1) + geom_point(aes(y=coefficient), col="navyblue", size=2) + geom_line(aes(y=coefficient), col="navyblue", size=0.5, group=1) + theme_classic() + geom_hline(yintercept=0, linetype="dashed") + geom_vline(xintercept=6, linetype="dashed") + labs(y="Daily Cases per 100,000", x="Days") + ylim(-0.002,0.004)
ggsave("BildNPIZ.png", plot = last_plot(), width = 8, height = 5, units = "in",dpi = 300)


reg1 <- lm(Faelle_pro_Einwohner ~ vorher_01 + vorher_02 + vorher_03 + vorher_04 + vorher_05 + vorher_06 + vorher_07 + vorher_08 + vorher_09 + vorher_10 + vorher_11 + vorher_12 + vorher_13 + vorher_14 + vorher_15 + vorher_16 + vorher_17 + vorher_18 + vorher_19 + vorher_20 + vorher_21 + vorher_22 + danach_01 + danach_02 + danach_03 + danach_04 + danach_05 + danach_06 + danach_07 + danach_08 + danach_09 + danach_10 + danach_11 + danach_12 + danach_13 + danach_14 + danach_15 + parks + grocery + retail + stations + workplaces + residential + m1 + m2 + m3 + m4 + m5 + m6 + m7 + m8 + m9 + m10 + m11 + m12 + m13 + m14 + m15 + m16 + m17 + m18 + m19 + m20 + m21 + m22 + m23    + factor(IdLandkreis) + factor(Meldedatum) + factor(IdBundesland):factor(week)  +0, Panel[Panel$Meldedatum>"2020-08-09" & Panel$Meldedatum<"2020-11-09",])
a <- coeftest(reg1, vcov = vcovCL(reg1, type = "HC1", cluster= ~IdLandkreis))
coefficient <- a[1:37,1]
st_error <- a[1:37,2]
timing <- c(1:22, -1:-15)
data <- as.data.frame(coefficient)
data$timing <- timing
data$st_error <- st_error
data[38,] <- c(0, 0, 0)
data$st_error <- as.numeric(data$st_error)*1.959964
data$coefficient <- as.numeric(data$coefficient)
data$timing <- as.numeric(data$timing)
#pic1 <- ggplot(data, aes(x=timing)) + geom_point(aes(y=coefficient), col="gray", size=2) + theme_classic() + geom_hline(yintercept=0, linetype="dashed") + geom_vline(xintercept=0, linetype="dashed") + labs(y="Daily Cases per 100,000", x="Days") + geom_errorbar(aes(ymin=coefficient-st_error, ymax=coefficient+st_error), width=.35, position=position_dodge(.9), col="gray") + ylim(-2.5,5.5) + geom_line(aes(y=coefficient), linetype="dashed", col="gray", size=1) + xlim(-14.5,21.5)
pic1 <- ggplot(data, aes(x=timing)) + geom_ribbon(aes(ymin=coefficient-st_error, ymax=coefficient+st_error), alpha=0.2, fill="blue") + geom_ribbon(aes(ymin=coefficient-st_error/1.959964*1.64, ymax=coefficient+st_error/1.959964*1.64), alpha=0.35, fill="blue") + geom_point(aes(y=coefficient), col="navyblue", size=2) + geom_line(aes(y=coefficient), col="navyblue", size=0.5) + theme_classic() + geom_hline(yintercept=0, linetype="dashed") + geom_vline(xintercept=0, linetype="dashed") + labs(y="Daily Cases per 100,000", x="Days") + ylim(-2.5,5.5) + xlim(-14.5,21.5)
ggsave("NPIs.png", plot = last_plot(), width = 8, height = 5, units = "in",dpi = 300)
pic1 <- ggplot(data, aes(x=timing)) + geom_ribbon(aes(ymin=coefficient-st_error, ymax=coefficient+st_error), alpha=0.2, fill="blue") + geom_ribbon(aes(ymin=coefficient-st_error/1.959964*1.64, ymax=coefficient+st_error/1.959964*1.64), alpha=0.35, fill="blue") + geom_point(aes(y=coefficient), col="navyblue", size=2) + geom_line(aes(y=coefficient), col="navyblue", size=0.5) + theme_classic() + geom_hline(yintercept=0, linetype="dashed") + geom_vline(xintercept=0, linetype="dashed") + labs(y="Daily Cases per 100,000", x="Days") + ylim(-0.002,0.004) + xlim(-14.5,21.5)
ggsave("NPIs_Z.png", plot = last_plot(), width = 8, height = 5, units = "in",dpi = 300)

## Figure A3
NPI <- summarize(group_by(Panel, Meldedatum), m1=mean(m1, na.rm=TRUE), m2=mean(m2, na.rm=TRUE), m3=mean(m3, na.rm=TRUE),
                 m4=mean(m4, na.rm=TRUE), m5=mean(m5, na.rm=TRUE), m6=mean(m6, na.rm=TRUE), m7=mean(m7, na.rm=TRUE),
                 m8=mean(m8, na.rm=TRUE), m9=mean(m9, na.rm=TRUE), m10=mean(m10, na.rm=TRUE), m11=mean(m11, na.rm=TRUE),
                 m12=mean(m12, na.rm=TRUE), m13=mean(m13, na.rm=TRUE), m14=mean(m14, na.rm=TRUE), m15=mean(m15, na.rm=TRUE),
                 m16=mean(m16, na.rm=TRUE), m17=mean(m17, na.rm=TRUE), m18=mean(m18, na.rm=TRUE), m19=mean(m19, na.rm=TRUE),
                 m20=mean(m20, na.rm=TRUE), m21=mean(m21, na.rm=TRUE), m22=mean(m22, na.rm=TRUE), m23=mean(m23, na.rm=TRUE))
NPI <- NPI[NPI$Meldedatum>"2020-08-09" & NPI$Meldedatum<"2020-11-09",]
pm1 <- ggplot(NPI, aes(Meldedatum, m1)) + geom_line() + theme_classic() + labs(title="Contact Restrictions (Private)", x="Date", y="Share of Counties With Respective NPI in Place") + ylim(0,1) + theme(plot.title = element_text(hjust = 0.5))
pm2 <- ggplot(NPI, aes(Meldedatum, m2)) + geom_line() + theme_classic() + labs(title="Contact Restrictions (Public)", x="Date", y="Share of Counties With Respective NPI in Place") + ylim(0,1) + theme(plot.title = element_text(hjust = 0.5))
pm3 <- ggplot(NPI, aes(Meldedatum, m3)) + geom_line() + theme_classic() + labs(title="Restrictions Secondary School", x="Date", y="Share of Counties With Respective NPI in Place") + ylim(0,1) + theme(plot.title = element_text(hjust = 0.5))
pm4 <- ggplot(NPI, aes(Meldedatum, m4)) + geom_line() + theme_classic() + labs(title="Restrictions Primary School", x="Date", y="Share of Counties With Respective NPI in Place") + ylim(0,1) + theme(plot.title = element_text(hjust = 0.5))
pm5 <- ggplot(NPI, aes(Meldedatum, m5)) + geom_line() + theme_classic() + labs(title="Restrictions Kindergarden", x="Date", y="Share of Counties With Respective NPI in Place") + ylim(0,1) + theme(plot.title = element_text(hjust = 0.5))
pm6 <- ggplot(NPI, aes(Meldedatum, m6)) + geom_line() + theme_classic() + labs(title="Restrictions Indoor Events", x="Date", y="Share of Counties With Respective NPI in Place") + ylim(0,1) + theme(plot.title = element_text(hjust = 0.5))
pm7 <- ggplot(NPI, aes(Meldedatum, m7)) + geom_line() + theme_classic() + labs(title="Restrictions Outdoor Events", x="Date", y="Share of Counties With Respective NPI in Place") + ylim(0,1) + theme(plot.title = element_text(hjust = 0.5))
pm8 <- ggplot(NPI, aes(Meldedatum, m8)) + geom_line() + theme_classic() + labs(title="Restrictions Cultural/Educational Institutions", x="Date", y="Share of Counties With Respective NPI in Place") + ylim(0,1) + theme(plot.title = element_text(hjust = 0.5))
pm9 <- ggplot(NPI, aes(Meldedatum, m9)) + geom_line() + theme_classic() + labs(title="Restrictions Wholesale/Retailing", x="Date", y="Share of Counties With Respective NPI in Place") + ylim(0,1) + theme(plot.title = element_text(hjust = 0.5))
pm10 <- ggplot(NPI, aes(Meldedatum, m10)) + geom_line() + theme_classic() + labs(title="Restrictions Restaurants", x="Date", y="Share of Counties With Respective NPI in Place") + ylim(0,1) + theme(plot.title = element_text(hjust = 0.5))
pm11 <- ggplot(NPI, aes(Meldedatum, m11)) + geom_line() + theme_classic() + labs(title="Restrictions Services/Craft", x="Date", y="Share of Counties With Respective NPI in Place") + ylim(0,1) + theme(plot.title = element_text(hjust = 0.5))
pm12 <- ggplot(NPI, aes(Meldedatum, m12)) + geom_line() + theme_classic() + labs(title="Restrictions Nightlife", x="Date", y="Share of Counties With Respective NPI in Place") + ylim(0,1) + theme(plot.title = element_text(hjust = 0.5))
pm13 <- ggplot(NPI, aes(Meldedatum, m13)) + geom_line() + theme_classic() + labs(title="Restrictions Accommodations", x="Date", y="Share of Counties With Respective NPI in Place") + ylim(0,1) + theme(plot.title = element_text(hjust = 0.5))
pm14 <- ggplot(NPI, aes(Meldedatum, m14)) + geom_line() + theme_classic() + labs(title="Restrictions Sport Indoor", x="Date", y="Share of Counties With Respective NPI in Place") + ylim(0,1) + theme(plot.title = element_text(hjust = 0.5))
pm15 <- ggplot(NPI, aes(Meldedatum, m15)) + geom_line() + theme_classic() + labs(title="Restrictions Sport Outdoor", x="Date", y="Share of Counties With Respective NPI in Place") + ylim(0,1) + theme(plot.title = element_text(hjust = 0.5))
pm16 <- ggplot(NPI, aes(Meldedatum, m16)) + geom_line() + theme_classic() + labs(title="Restrictions National Travel", x="Date", y="Share of Counties With Respective NPI in Place") + ylim(0,1) + theme(plot.title = element_text(hjust = 0.5))
pm17 <- ggplot(NPI, aes(Meldedatum, m17)) + geom_line() + theme_classic() + labs(title="Restrictions International Travel", x="Date", y="Share of Counties With Respective NPI in Place") + ylim(0,1) + theme(plot.title = element_text(hjust = 0.5))
pm18 <- ggplot(NPI, aes(Meldedatum, m18)) + geom_line() + theme_classic() + labs(title="Compulsory Masks", x="Date", y="Share of Counties With Respective NPI in Place") + ylim(0,1) + theme(plot.title = element_text(hjust = 0.5))
pm19 <- ggplot(NPI, aes(Meldedatum, m19)) + geom_line() + theme_classic() + labs(title="Restrictions Workplace", x="Date", y="Share of Counties With Respective NPI in Place") + ylim(0,1) + theme(plot.title = element_text(hjust = 0.5))
pm20 <- ggplot(NPI, aes(Meldedatum, m20)) + geom_line() + theme_classic() + labs(title="Curfews", x="Date", y="Share of Counties With Respective NPI in Place") + ylim(0,1) + theme(plot.title = element_text(hjust = 0.5))
pm21 <- ggplot(NPI, aes(Meldedatum, m21)) + geom_line() + theme_classic() + labs(title="Capacity Restrictions Public Transport", x="Date", y="Share of Counties With Respective NPI in Place") + ylim(0,1) + theme(plot.title = element_text(hjust = 0.5))
pm22 <- ggplot(NPI, aes(Meldedatum, m22)) + geom_line() + theme_classic() + labs(title="Physical Distancing", x="Date", y="Share of Counties With Respective NPI in Place") + ylim(0,1) + theme(plot.title = element_text(hjust = 0.5))
pm23 <- ggplot(NPI, aes(Meldedatum, m23)) + geom_line() + theme_classic() + labs(title="Additional Testing Measures", x="Date", y="Share of Counties With Respective NPI in Place") + ylim(0,1) + theme(plot.title = element_text(hjust = 0.5))






# Load Data
Panel <- read_csv("Panel.csv")
Panel <- Panel[,-1]
Panel <- data.frame(Panel)
NPI <- read_csv("NPI.csv")

Panel$Spiel_pro_Einwohner <- Panel$Spiel/Panel$Einwohner*100000
Panel$Spiel_pro_Einwohner[is.na(Panel$Spiel_pro_Einwohner)] <- 0
#Panel$Spiel_pro_Einwohner <- Panel$Zuschauer/Panel$Einwohner*100000
#Panel$Spiel_pro_Einwohner[is.na(Panel$Spiel_pro_Einwohner)] <- 0
#Panel$Spiel <- log(Panel$Zuschauer)
#Panel$Spiel[is.na(Panel$Spiel)] <- 0
#Panel$Spiel <- Panel$Spiel_pro_Einwohner
Panel$vorher_01 <- 0
Panel$vorher_02 <- 0
Panel$vorher_03 <- 0
Panel$vorher_04 <- 0
Panel$vorher_05 <- 0
Panel$vorher_06 <- 0
Panel$vorher_07 <- 0
Panel$vorher_08 <- 0
Panel$vorher_09 <- 0
Panel$vorher_10 <- 0
Panel$vorher_11 <- 0
Panel$vorher_12 <- 0
Panel$vorher_13 <- 0
Panel$vorher_14 <- 0
Panel$vorher_15 <- 0
Panel$vorher_16 <- 0
Panel$vorher_17 <- 0
Panel$vorher_18 <- 0
Panel$vorher_19 <- 0
Panel$vorher_20 <- 0
Panel$vorher_21 <- 0
Panel$vorher_22 <- 0
for (i in 1:22){
  a <- i
  b <- 75+i
  Panel[,b] <- dplyr::lag(Panel$Spiel_pro_Einwohner, a)
  Panel$lag_Kreis <- dplyr::lag(Panel$IdLandkreis, a)
  Panel[,b][Panel$lag_Kreis!=Panel$IdLandkreis] <- 0
  Panel[,b][is.na(Panel[,b])] <- 0
}
Panel$danach_01 <- 0
Panel$danach_02 <- 0
Panel$danach_03 <- 0
Panel$danach_04 <- 0
Panel$danach_05 <- 0
Panel$danach_06 <- 0
Panel$danach_07 <- 0
Panel$danach_08 <- 0
Panel$danach_09 <- 0
Panel$danach_10 <- 0
Panel$danach_11 <- 0
Panel$danach_12 <- 0
Panel$danach_13 <- 0
Panel$danach_14 <- 0
Panel$danach_15 <- 0
for (i in 1:15){
  a <- i
  b <- 98+i
  Panel[,b] <- dplyr::lead(Panel$Spiel_pro_Einwohner, a)
  Panel$lag_Kreis <- dplyr::lead(Panel$IdLandkreis, a)
  Panel[,b][Panel$lag_Kreis!=Panel$IdLandkreis] <- 0
  Panel[,b][is.na(Panel[,b])] <- 0
}
Panel$Faelle_pro_Einwohner <- Panel$Faelle/Panel$Einwohner*100000
Panel$vorher_22[is.na(Panel$vorher_22)] <- 0
Panel$danach_15[is.na(Panel$danach_15)] <- 0
for (i in unique(Panel$IdLandkreis)){
  a <- Panel[Panel$IdLandkreis==i,]
  a$vorher_22 <- cumsum(a$vorher_22)
  Panel$vorher_22[Panel$IdLandkreis==i] <- a$vorher_22
}
for (i in unique(Panel$IdLandkreis)){
  a <- Panel[Panel$IdLandkreis==i,]
  a$danach_15 <- rev(cumsum(rev(a$danach_15)))
  Panel$danach_15[Panel$IdLandkreis==i] <- a$danach_15
}
Panel$weekday <- weekdays(as.Date(Panel$Meldedatum))

## Data on NPIs
Panel <- left_join(Panel, NPI, by = c("IdLandkreis" = "ags5", "Meldedatum" = "Datum"))

# Binned Results
Panel$vorher0103 <- Panel$vorher_01+Panel$vorher_02+Panel$vorher_03
Panel$vorher0406 <- Panel$vorher_04+Panel$vorher_05+Panel$vorher_06
Panel$vorher0709 <- Panel$vorher_07+Panel$vorher_08+Panel$vorher_09
Panel$vorher1012 <- Panel$vorher_10+Panel$vorher_11+Panel$vorher_12
Panel$vorher1315 <- Panel$vorher_13+Panel$vorher_14+Panel$vorher_15
Panel$vorher1618 <- Panel$vorher_16+Panel$vorher_17+Panel$vorher_18
Panel$vorher1921 <- Panel$vorher_19+Panel$vorher_20+Panel$vorher_21
#Panel$vorher2224 <- Panel$vorher_22+Panel$vorher_23+Panel$vorher_24
#Panel$vorher2528 <- Panel$vorher_25+Panel$vorher_26+Panel$vorher_27+Panel$vorher_28
Panel$danach0103 <- Panel$danach_01+Panel$danach_02+Panel$danach_03
Panel$danach0406 <- Panel$danach_04+Panel$danach_05+Panel$danach_06
Panel$danach0709 <- Panel$danach_07+Panel$danach_08+Panel$danach_09
Panel$danach1012 <- Panel$danach_10+Panel$danach_11+Panel$danach_12
Panel$danach1314 <- Panel$danach_13+Panel$danach_14
Panel$stateweek <- paste(Panel$IdBundesland, Panel$week)

# Figure A21: Left Plot
reg1 <- summary(feols(Faelle_pro_Einwohner ~ vorher0103 + vorher0406 + vorher0709 + vorher1012 + vorher1315 + vorher1618 + vorher1921 + vorher_22 +
                        danach0103 + danach0406 + danach0709 + danach1012 + danach1314 + danach_15 + parks + grocery + retail + stations + workplaces + residential +
                        m1 + m2 + m3 + m4 + m5 + m6 + m7 + m8 + m9 + m10 + m11 + m12 + m13 + m14 + m15 + m16 + m17 + m18 + m19 + m20 + m21 + m22 + m23| IdLandkreis + Meldedatum + stateweek  +0, Panel[Panel$Meldedatum>"2020-08-09" & Panel$Meldedatum<"2020-11-09",], cluster= ~IdLandkreis))
coefficient <- reg1$coefficients[c(1:7,9:13)]
st_error <- reg1$se[c(1:7,9:13)]*1.96
timing <- c(" [1,3]", " [4,6]", " [7,9]", "[10,12]", "[13,15]","[16,18]", "[19,21]", " [-3,-1]", "  [-6,-4]", "   [-9,-7]", "   [-12,-10]", "    [-14,-13]")
data <- as.data.frame(cbind(coefficient, st_error, timing))
data[13,] <- c(0,0," [0]")
data$coefficient <- as.numeric(data$coefficient)
data$st_error <- as.numeric(data$st_error)
ggplot(data, aes(x=timing)) + geom_ribbon(aes(ymin=coefficient-st_error, ymax=coefficient+st_error), alpha=0.2, fill="blue", group=1) + geom_ribbon(aes(ymin=coefficient-st_error/1.959964*1.64, ymax=coefficient+st_error/1.959964*1.64), alpha=0.35, fill="blue", group=1) + geom_point(aes(y=coefficient), col="navyblue", size=2) + geom_line(aes(y=coefficient), col="navyblue", size=0.5, group=1) + theme_classic() + geom_hline(yintercept=0, linetype="dashed") + geom_vline(xintercept=6, linetype="dashed") + labs(y="Daily Cases per 100,000", x="Days") + ylim(-2.5, 5.5)









# Load Data
Panel <- read_csv("Panel.csv")
Panel <- Panel[,-1]
Panel <- data.frame(Panel)
NPI <- read_csv("NPI.csv")

Panel$Spiel_pro_Einwohner <- Panel$Zuschauer/Panel$Einwohner*100000
Panel$Spiel_pro_Einwohner[is.na(Panel$Spiel_pro_Einwohner)] <- 0
#Panel$Spiel_pro_Einwohner <- Panel$Zuschauer/Panel$Einwohner*100000
#Panel$Spiel_pro_Einwohner[is.na(Panel$Spiel_pro_Einwohner)] <- 0
#Panel$Spiel <- log(Panel$Zuschauer)
#Panel$Spiel[is.na(Panel$Spiel)] <- 0
#Panel$Spiel <- Panel$Spiel_pro_Einwohner
Panel$vorher_01 <- 0
Panel$vorher_02 <- 0
Panel$vorher_03 <- 0
Panel$vorher_04 <- 0
Panel$vorher_05 <- 0
Panel$vorher_06 <- 0
Panel$vorher_07 <- 0
Panel$vorher_08 <- 0
Panel$vorher_09 <- 0
Panel$vorher_10 <- 0
Panel$vorher_11 <- 0
Panel$vorher_12 <- 0
Panel$vorher_13 <- 0
Panel$vorher_14 <- 0
Panel$vorher_15 <- 0
Panel$vorher_16 <- 0
Panel$vorher_17 <- 0
Panel$vorher_18 <- 0
Panel$vorher_19 <- 0
Panel$vorher_20 <- 0
Panel$vorher_21 <- 0
Panel$vorher_22 <- 0
for (i in 1:22){
  a <- i
  b <- 75+i
  Panel[,b] <- dplyr::lag(Panel$Spiel_pro_Einwohner, a)
  Panel$lag_Kreis <- dplyr::lag(Panel$IdLandkreis, a)
  Panel[,b][Panel$lag_Kreis!=Panel$IdLandkreis] <- 0
  Panel[,b][is.na(Panel[,b])] <- 0
}
Panel$danach_01 <- 0
Panel$danach_02 <- 0
Panel$danach_03 <- 0
Panel$danach_04 <- 0
Panel$danach_05 <- 0
Panel$danach_06 <- 0
Panel$danach_07 <- 0
Panel$danach_08 <- 0
Panel$danach_09 <- 0
Panel$danach_10 <- 0
Panel$danach_11 <- 0
Panel$danach_12 <- 0
Panel$danach_13 <- 0
Panel$danach_14 <- 0
Panel$danach_15 <- 0
for (i in 1:15){
  a <- i
  b <- 98+i
  Panel[,b] <- dplyr::lead(Panel$Spiel_pro_Einwohner, a)
  Panel$lag_Kreis <- dplyr::lead(Panel$IdLandkreis, a)
  Panel[,b][Panel$lag_Kreis!=Panel$IdLandkreis] <- 0
  Panel[,b][is.na(Panel[,b])] <- 0
}
Panel$Faelle_pro_Einwohner <- Panel$Faelle/Panel$Einwohner*100000
Panel$vorher_22[is.na(Panel$vorher_22)] <- 0
Panel$danach_15[is.na(Panel$danach_15)] <- 0
for (i in unique(Panel$IdLandkreis)){
  a <- Panel[Panel$IdLandkreis==i,]
  a$vorher_22 <- cumsum(a$vorher_22)
  Panel$vorher_22[Panel$IdLandkreis==i] <- a$vorher_22
}
for (i in unique(Panel$IdLandkreis)){
  a <- Panel[Panel$IdLandkreis==i,]
  a$danach_15 <- rev(cumsum(rev(a$danach_15)))
  Panel$danach_15[Panel$IdLandkreis==i] <- a$danach_15
}
Panel$weekday <- weekdays(as.Date(Panel$Meldedatum))

## Data on NPIs
Panel <- left_join(Panel, NPI, by = c("IdLandkreis" = "ags5", "Meldedatum" = "Datum"))

# Binned Results
Panel$vorher0103 <- Panel$vorher_01+Panel$vorher_02+Panel$vorher_03
Panel$vorher0406 <- Panel$vorher_04+Panel$vorher_05+Panel$vorher_06
Panel$vorher0709 <- Panel$vorher_07+Panel$vorher_08+Panel$vorher_09
Panel$vorher1012 <- Panel$vorher_10+Panel$vorher_11+Panel$vorher_12
Panel$vorher1315 <- Panel$vorher_13+Panel$vorher_14+Panel$vorher_15
Panel$vorher1618 <- Panel$vorher_16+Panel$vorher_17+Panel$vorher_18
Panel$vorher1921 <- Panel$vorher_19+Panel$vorher_20+Panel$vorher_21
#Panel$vorher2224 <- Panel$vorher_22+Panel$vorher_23+Panel$vorher_24
#Panel$vorher2528 <- Panel$vorher_25+Panel$vorher_26+Panel$vorher_27+Panel$vorher_28
Panel$danach0103 <- Panel$danach_01+Panel$danach_02+Panel$danach_03
Panel$danach0406 <- Panel$danach_04+Panel$danach_05+Panel$danach_06
Panel$danach0709 <- Panel$danach_07+Panel$danach_08+Panel$danach_09
Panel$danach1012 <- Panel$danach_10+Panel$danach_11+Panel$danach_12
Panel$danach1314 <- Panel$danach_13+Panel$danach_14
Panel$stateweek <- paste(Panel$IdBundesland, Panel$week)

# Figure A21: Right Plot
reg1 <- summary(feols(Faelle_pro_Einwohner ~ vorher0103 + vorher0406 + vorher0709 + vorher1012 + vorher1315 + vorher1618 + vorher1921 + vorher_22 +
                        danach0103 + danach0406 + danach0709 + danach1012 + danach1314 + danach_15 + parks + grocery + retail + stations + workplaces + residential +
                        m1 + m2 + m3 + m4 + m5 + m6 + m7 + m8 + m9 + m10 + m11 + m12 + m13 + m14 + m15 + m16 + m17 + m18 + m19 + m20 + m21 + m22 + m23| IdLandkreis + Meldedatum + stateweek  +0, Panel[Panel$Meldedatum>"2020-08-09" & Panel$Meldedatum<"2020-11-09",], cluster= ~IdLandkreis))
coefficient <- reg1$coefficients[c(1:7,9:13)]
st_error <- reg1$se[c(1:7,9:13)]*1.96
timing <- c(" [1,3]", " [4,6]", " [7,9]", "[10,12]", "[13,15]","[16,18]", "[19,21]", " [-3,-1]", "  [-6,-4]", "   [-9,-7]", "   [-12,-10]", "    [-14,-13]")
data <- as.data.frame(cbind(coefficient, st_error, timing))
data[13,] <- c(0,0," [0]")
data$coefficient <- as.numeric(data$coefficient)
data$st_error <- as.numeric(data$st_error)
ggplot(data, aes(x=timing)) + geom_ribbon(aes(ymin=coefficient-st_error, ymax=coefficient+st_error), alpha=0.2, fill="blue", group=1) + geom_ribbon(aes(ymin=coefficient-st_error/1.959964*1.64, ymax=coefficient+st_error/1.959964*1.64), alpha=0.35, fill="blue", group=1) + geom_point(aes(y=coefficient), col="navyblue", size=2) + geom_line(aes(y=coefficient), col="navyblue", size=0.5, group=1) + theme_classic() + geom_hline(yintercept=0, linetype="dashed") + geom_vline(xintercept=6, linetype="dashed") + labs(y="Daily Cases per 100,000", x="Days") + ylim(-0.002,0.004)
