## Replication Figure A4-A5

# Load Packages
library(readr)
library(readxl)
library(dplyr)
library(ggplot2)
library(lmtest)
library(stargazer)
library(sandwich)
library(lubridate)
library(AER)
library(scales)
library(pscl)
library(plm)
library(urca)
library(tseries)
library(EventStudy)
library(gridExtra)
library(mfx)
library(stringr)
library(sf)
library(fixest)

# Set Working Directory to the 'Data' Folder of the Replication Package
setwd("XXX")

# Load Data
Fallzahlen <- read_csv("Fallzahlen.csv")

### Figure A4
Faelle <- Fallzahlen[as.Date(Fallzahlen$Meldedatum)<"2020-12-07",]
Faelle <- group_by(Faelle, Meldedatum)
Faelle <- summarize(Faelle, Cases=sum(AnzahlFall), Measure=sum(AnzahlTodesfall))
a <- nrow(Faelle)
Faelle <- bind_rows(Faelle, Faelle)
Faelle$Cases[(a+1):(2*a)] <- Faelle$Measure[(a+1):(2*a)]
Faelle$Measure <- "COVID-19 Cases"
Faelle$Measure[(a+1):(2*a)] <- "COVID-19 Deaths"
Faelle$Number <- cumsum(Faelle$Cases)
Faelle$Number <- (cumsum(Faelle$Cases)-dplyr::lag(Faelle$Number,7))/7
Faelle$Number[Faelle$Measure=="COVID-19 Deaths"] <- Faelle$Number[Faelle$Measure=="COVID-19 Deaths"]*10
ggplot(Faelle[as.Date(Faelle$Meldedatum)<"2020-12-07" & as.Date(Faelle$Meldedatum)>"2020-02-28",], aes(as.Date(Meldedatum), Number)) + geom_line(aes(col=Measure), size=1.15) + theme(legend.title=element_blank()) + theme_classic() + labs(x="", y="") + scale_y_continuous("Number of Cases", sec.axis = sec_axis(~ . * 0.1, name = "Number of Deaths")) + scale_color_grey() + theme(legend.title = element_blank()) + theme(legend.position="bottom") + geom_vline(xintercept=as.Date("2020-11-03")) + annotate(geom="text", x=as.Date("2020-10-10"), y=18000, label="Semi-Lockdown", fontface=2) + annotate(geom="text", x=as.Date("2020-10-10"), y=17000, label="(2020/11/02)", fontface=1) + scale_colour_manual("legend", values = c("COVID-19 Cases" = alpha("navyblue", .5), "COVID-19 Deaths" = alpha("navyblue", .2)))

### Figure A5
Faelle <- Fallzahlen
Faelle <- Faelle[Faelle$Altersgruppe!="unbekannt",]
Faelle$Altersgruppe[Faelle$Altersgruppe=="A60-A79"] <- "A60+"
Faelle$Altersgruppe[Faelle$Altersgruppe=="A80+"] <- "A60+"
Faelle$Altersgruppe[Faelle$Altersgruppe=="A00-A04"] <- "A00-A14"
Faelle$Altersgruppe[Faelle$Altersgruppe=="A05-A14"] <- "A00-A14"
Faelle <- group_by(Faelle, Altersgruppe, Meldedatum)
Faelle <- summarize(Faelle, Cases=sum(AnzahlFall))
a <- summarize(group_by(ungroup(Faelle), Meldedatum), Cases_overall=sum(Cases))
Faelle <- left_join(Faelle, a, by = "Meldedatum")
Faelle$Share <- Faelle$Cases/Faelle$Cases_overall
Faelle$Age <- Faelle$Altersgruppe
Faelle$Meldedatum <- as.Date(Faelle$Meldedatum)
p1 <- ggplot(Faelle[Faelle$Meldedatum>"2020-02-28" & Faelle$Meldedatum<"2020-12-07" & Faelle$Altersgruppe=="A00-A14",], aes(Meldedatum, Share)) + geom_line(aes(linetype=Age), size=0.7, col="navyblue") + theme_classic() + labs(y="Share of Daily COVID-19 Cases", x="") + theme(legend.title = element_blank()) + theme(legend.position = c(0.85, 0.85)) + scale_color_grey() +ylim(0,0.65)
p2 <- ggplot(Faelle[Faelle$Meldedatum>"2020-02-28" & Faelle$Meldedatum<"2020-12-07" & Faelle$Altersgruppe=="A15-A34",], aes(Meldedatum, Share)) + geom_line(aes(linetype=Age), size=0.7, col="navyblue") + theme_classic() + labs(y="Share of Daily COVID-19 Cases", x="") + theme(legend.title = element_blank()) + theme(legend.position = c(0.85, 0.85)) + scale_color_grey() +ylim(0,0.65)
p3 <- ggplot(Faelle[Faelle$Meldedatum>"2020-02-28" & Faelle$Meldedatum<"2020-12-07" & Faelle$Altersgruppe=="A35-A59",], aes(Meldedatum, Share)) + geom_line(aes(linetype=Age), size=0.7, col="navyblue") + theme_classic() + labs(y="Share of Daily COVID-19 Cases", x="") + theme(legend.title = element_blank()) + theme(legend.position = c(0.85, 0.85)) + scale_color_grey() +ylim(0,0.65)
p4 <- ggplot(Faelle[Faelle$Meldedatum>"2020-02-28" & Faelle$Meldedatum<"2020-12-07" & Faelle$Altersgruppe=="A60+",], aes(Meldedatum, Share)) + geom_line(aes(linetype=Age), size=0.7, col="navyblue") + theme_classic() + labs(y="Share of Daily COVID-19 Cases", x="") + theme(legend.title = element_blank()) + theme(legend.position = c(0.85, 0.85)) + scale_color_grey() +ylim(0,0.65)