## Replication Figure A6 and A7

# Load Packages
library(readr)
library(readxl)
library(dplyr)
library(ggplot2)
library(lmtest)
library(stargazer)
library(sandwich)
library(lubridate)
library(AER)
library(scales)
library(pscl)
library(plm)
library(urca)
library(tseries)
library(EventStudy)
library(gridExtra)
library(mfx)
library(stringr)
library(sf)
library(fixest)

# Set Working Directory to the 'Data' Folder of the Replication Package
setwd("XXX")

# Load Data
Panel <- read_csv("Panelhet.csv")
Panel <- as.data.frame(Panel[,-1])
Einwohnerzahlen <- read_excel("Einwohnerzahlen.xlsx")
Alter <- read_csv("Alter.csv")

Panel <- left_join(Panel, dplyr::select(Alter[Alter$Altersgruppe=="A00-A14",], IdLandkreis, Meldedatum, Faelle_Age), by = c("Meldedatum", "IdLandkreis"))
Panel$Faelle_0014 <- Panel$Faelle_Age
Panel$Faelle_Age <- NULL
Panel$Faelle_0014[is.na(Panel$Faelle_0014)] <- 0
Panel <- left_join(Panel, dplyr::select(Alter[Alter$Altersgruppe=="A15-A34",], IdLandkreis, Meldedatum, Faelle_Age), by = c("Meldedatum", "IdLandkreis"))
Panel$Faelle_1534 <- Panel$Faelle_Age
Panel$Faelle_Age <- NULL
Panel$Faelle_1534[is.na(Panel$Faelle_1534)] <- 0
Panel <- left_join(Panel, dplyr::select(Alter[Alter$Altersgruppe=="A35-A59",], IdLandkreis, Meldedatum, Faelle_Age), by = c("Meldedatum", "IdLandkreis"))
Panel$Faelle_3559 <- Panel$Faelle_Age
Panel$Faelle_Age <- NULL
Panel$Faelle_3559[is.na(Panel$Faelle_3559)] <- 0
Panel <- left_join(Panel, dplyr::select(Alter[Alter$Altersgruppe=="A60+",], IdLandkreis, Meldedatum, Faelle_Age), by = c("Meldedatum", "IdLandkreis"))
Panel$Faelle_60 <- Panel$Faelle_Age
Panel$Faelle_Age <- NULL
Panel$Faelle_60[is.na(Panel$Faelle_60)] <- 0
for (i in 1:nrow(Altersgruppen)){
  Altersgruppen$IdLandkreis[i] <- ifelse(is.na(Altersgruppen$IdLandkreis[i]), dplyr::lag(Altersgruppen$IdLandkreis)[i], Altersgruppen$IdLandkreis[i])
}
Altersgruppen <- Altersgruppen[Altersgruppen$Altersgruppe!="Insgesamt",]
Panel <- left_join(Panel, dplyr::select(Altersgruppen[Altersgruppen$Altersgruppe=="A00-A14",], IdLandkreis, Einwohner_Age), by = "IdLandkreis")
Panel$Einwohner_A0014 <- Panel$Einwohner_Age
Panel$Einwohner_Age <- NULL
Panel <- left_join(Panel, dplyr::select(Altersgruppen[Altersgruppen$Altersgruppe=="A15-A34",], IdLandkreis, Einwohner_Age), by = "IdLandkreis")
Panel$Einwohner_A1534 <- Panel$Einwohner_Age
Panel$Einwohner_Age <- NULL
Panel <- left_join(Panel, dplyr::select(Altersgruppen[Altersgruppen$Altersgruppe=="A35-A59",], IdLandkreis, Einwohner_Age), by = "IdLandkreis")
Panel$Einwohner_A3559 <- Panel$Einwohner_Age
Panel$Einwohner_Age <- NULL
Panel <- left_join(Panel, dplyr::select(Altersgruppen[Altersgruppen$Altersgruppe=="A60+",], IdLandkreis, Einwohner_Age), by = "IdLandkreis")
Panel$Einwohner_A60 <- Panel$Einwohner_Age
Panel$Einwohner_Age <- NULL
Panel$Einwohner_A0014[Panel$IdLandkreis=="02000"] <- Altersgruppen$Einwohner_Age[Altersgruppen$Altersgruppe=="A00-A14" & Altersgruppen$IdLandkreis=="02"]
Panel$Einwohner_A1534[Panel$IdLandkreis=="02000"] <- Altersgruppen$Einwohner_Age[Altersgruppen$Altersgruppe=="A15-A34" & Altersgruppen$IdLandkreis=="02"]
Panel$Einwohner_A3559[Panel$IdLandkreis=="02000"] <- Altersgruppen$Einwohner_Age[Altersgruppen$Altersgruppe=="A35-A59" & Altersgruppen$IdLandkreis=="02"]
Panel$Einwohner_A60[Panel$IdLandkreis=="02000"] <- Altersgruppen$Einwohner_Age[Altersgruppen$Altersgruppe=="A60+" & Altersgruppen$IdLandkreis=="02"]

########################################################### Regressions on Age Heterogeneity (Match) ##################
Panel$Spiel <- NULL
Panel$Zuschauer <- NULL
Panel <- left_join(Panel, summarize(group_by(Spiele, Datum, Heimkreis), Spiel=sum(Spiel), Zuschauer=sum(Zuschauer)), by = c("Meldedatum" = "Datum", "IdLandkreis" = "Heimkreis"))
Panel$Zuschauer[is.na(Panel$Zuschauer)] <- 0
Panel$Spiel[is.na(Panel$Spiel)] <- 0
Panel[,74:95] <- 0
Panel$Spiel_pro_Einwohner <- Panel$Spiel/Panel$Einwohner_A0014*100000
for (i in 1:22){
  a <- i
  b <- 73+i
  Panel[,b] <- dplyr::lag(Panel$Spiel_pro_Einwohner, a)
  Panel$lag_Kreis <- dplyr::lag(Panel$IdLandkreis, a)
  Panel[,b][Panel$lag_Kreis!=Panel$IdLandkreis] <- 0
  Panel[,b][is.na(Panel[,b])] <- 0
}
Panel[,97:111] <- 0
for (i in 1:15){
  a <- i
  b <- 96+i
  Panel[,b] <- dplyr::lead(Panel$Spiel_pro_Einwohner, a)
  Panel$lag_Kreis <- dplyr::lead(Panel$IdLandkreis, a)
  Panel[,b][Panel$lag_Kreis!=Panel$IdLandkreis] <- 0
  Panel[,b][is.na(Panel[,b])] <- 0
}
Panel$Faelle_pro_Einwohner_0014 <- Panel$Faelle_0014/Panel$Einwohner_A0014*100000
Panel$Faelle_pro_Einwohner_1534 <- Panel$Faelle_1534/Panel$Einwohner_A1534*100000
Panel$Faelle_pro_Einwohner_3559 <- Panel$Faelle_3559/Panel$Einwohner_A3559*100000
Panel$Faelle_pro_Einwohner_60 <- Panel$Faelle_60/Panel$Einwohner_A60*100000
Panel$vorher_22[is.na(Panel$vorher_22)] <- 0
Panel$danach_15[is.na(Panel$danach_15)] <- 0
for (i in unique(Panel$IdLandkreis)){
  a <- Panel[Panel$IdLandkreis==i,]
  a$vorher_22 <- cumsum(a$vorher_22)
  Panel$vorher_22[Panel$IdLandkreis==i] <- a$vorher_22
}
for (i in unique(Panel$IdLandkreis)){
  a <- Panel[Panel$IdLandkreis==i,]
  a$danach_15 <- rev(cumsum(rev(a$danach_15)))
  Panel$danach_15[Panel$IdLandkreis==i] <- a$danach_15
}
# Binned Regressions
Panel$vorher0103 <- Panel$vorher_01+Panel$vorher_02+Panel$vorher_03
Panel$vorher0406 <- Panel$vorher_04+Panel$vorher_05+Panel$vorher_06
Panel$vorher0709 <- Panel$vorher_07+Panel$vorher_08+Panel$vorher_09
Panel$vorher1012 <- Panel$vorher_10+Panel$vorher_11+Panel$vorher_12
Panel$vorher1315 <- Panel$vorher_13+Panel$vorher_14+Panel$vorher_15
Panel$vorher1618 <- Panel$vorher_16+Panel$vorher_17+Panel$vorher_18
Panel$vorher1921 <- Panel$vorher_19+Panel$vorher_20+Panel$vorher_21
Panel$danach0103 <- Panel$danach_01+Panel$danach_02+Panel$danach_03
Panel$danach0406 <- Panel$danach_04+Panel$danach_05+Panel$danach_06
Panel$danach0709 <- Panel$danach_07+Panel$danach_08+Panel$danach_09
Panel$danach1012 <- Panel$danach_10+Panel$danach_11+Panel$danach_12
Panel$danach1314 <- Panel$danach_13+Panel$danach_14
reg1 <- summary(feols(Faelle_pro_Einwohner_0014 ~ vorher0103 + vorher0406 + vorher0709 + vorher1012 + vorher1315 + vorher1618 + vorher1921 + vorher_22 +
                        danach0103 + danach0406 + danach0709 + danach1012 + danach1314 + danach_15 + parks + grocery + retail + stations + workplaces + residential    | IdLandkreis + Meldedatum + stateweek  +0, Panel[Panel$Meldedatum>"2020-08-09" & Panel$Meldedatum<"2020-11-09",], cluster= ~IdLandkreis))
#reg1 <- lm(Faelle_pro_Einwohner_0014 ~ vorher_01 + vorher_02 + vorher_03 + vorher_04 + vorher_05 + vorher_06 + vorher_07 + vorher_08 + vorher_09 + vorher_10 + vorher_11 + vorher_12 + vorher_13 + vorher_14 + vorher_15 + vorher_16 + vorher_17 + vorher_18 + vorher_19 + vorher_20 + vorher_21 + vorher_22 + danach_01 + danach_02 + danach_03 + danach_04 + danach_05 + danach_06 + danach_07 + danach_08 + danach_09 + danach_10 + danach_11 + danach_12 + danach_13 + danach_14 + danach_15 + parks + grocery + retail + stations + workplaces + residential    + factor(IdLandkreis) + factor(Meldedatum) + factor(IdBundesland):factor(week)  +0, data=Panel[Panel$Meldedatum>"2020-08-09" & Panel$Meldedatum<"2020-11-09",])
Panel[,74:95] <- 0
Panel$Spiel_pro_Einwohner <- Panel$Spiel/Panel$Einwohner_A1534*100000
for (i in 1:22){
  a <- i
  b <- 73+i
  Panel[,b] <- dplyr::lag(Panel$Spiel_pro_Einwohner, a)
  Panel$lag_Kreis <- dplyr::lag(Panel$IdLandkreis, a)
  Panel[,b][Panel$lag_Kreis!=Panel$IdLandkreis] <- 0
  Panel[,b][is.na(Panel[,b])] <- 0
}
Panel[,97:111] <- 0
for (i in 1:15){
  a <- i
  b <- 96+i
  Panel[,b] <- dplyr::lead(Panel$Spiel_pro_Einwohner, a)
  Panel$lag_Kreis <- dplyr::lead(Panel$IdLandkreis, a)
  Panel[,b][Panel$lag_Kreis!=Panel$IdLandkreis] <- 0
  Panel[,b][is.na(Panel[,b])] <- 0
}
Panel$Faelle_pro_Einwohner_0014 <- Panel$Faelle_0014/Panel$Einwohner_A0014*100000
Panel$Faelle_pro_Einwohner_1534 <- Panel$Faelle_1534/Panel$Einwohner_A1534*100000
Panel$Faelle_pro_Einwohner_3559 <- Panel$Faelle_3559/Panel$Einwohner_A3559*100000
Panel$Faelle_pro_Einwohner_60 <- Panel$Faelle_60/Panel$Einwohner_A60*100000
Panel$vorher_22[is.na(Panel$vorher_22)] <- 0
Panel$danach_15[is.na(Panel$danach_15)] <- 0
for (i in unique(Panel$IdLandkreis)){
  a <- Panel[Panel$IdLandkreis==i,]
  a$vorher_22 <- cumsum(a$vorher_22)
  Panel$vorher_22[Panel$IdLandkreis==i] <- a$vorher_22
}
for (i in unique(Panel$IdLandkreis)){
  a <- Panel[Panel$IdLandkreis==i,]
  a$danach_15 <- rev(cumsum(rev(a$danach_15)))
  Panel$danach_15[Panel$IdLandkreis==i] <- a$danach_15
}
# Binned Regressions
Panel$vorher0103 <- Panel$vorher_01+Panel$vorher_02+Panel$vorher_03
Panel$vorher0406 <- Panel$vorher_04+Panel$vorher_05+Panel$vorher_06
Panel$vorher0709 <- Panel$vorher_07+Panel$vorher_08+Panel$vorher_09
Panel$vorher1012 <- Panel$vorher_10+Panel$vorher_11+Panel$vorher_12
Panel$vorher1315 <- Panel$vorher_13+Panel$vorher_14+Panel$vorher_15
Panel$vorher1618 <- Panel$vorher_16+Panel$vorher_17+Panel$vorher_18
Panel$vorher1921 <- Panel$vorher_19+Panel$vorher_20+Panel$vorher_21
Panel$danach0103 <- Panel$danach_01+Panel$danach_02+Panel$danach_03
Panel$danach0406 <- Panel$danach_04+Panel$danach_05+Panel$danach_06
Panel$danach0709 <- Panel$danach_07+Panel$danach_08+Panel$danach_09
Panel$danach1012 <- Panel$danach_10+Panel$danach_11+Panel$danach_12
Panel$danach1314 <- Panel$danach_13+Panel$danach_14
reg2 <- summary(feols(Faelle_pro_Einwohner_1534 ~ vorher0103 + vorher0406 + vorher0709 + vorher1012 + vorher1315 + vorher1618 + vorher1921 + vorher_22 +
                        danach0103 + danach0406 + danach0709 + danach1012 + danach1314 + danach_15 + parks + grocery + retail + stations + workplaces + residential    | IdLandkreis + Meldedatum + stateweek  +0, Panel[Panel$Meldedatum>"2020-08-09" & Panel$Meldedatum<"2020-11-09",], cluster= ~IdLandkreis))
#reg2 <- lm(Faelle_pro_Einwohner_1534 ~ vorher_01 + vorher_02 + vorher_03 + vorher_04 + vorher_05 + vorher_06 + vorher_07 + vorher_08 + vorher_09 + vorher_10 + vorher_11 + vorher_12 + vorher_13 + vorher_14 + vorher_15 + vorher_16 + vorher_17 + vorher_18 + vorher_19 + vorher_20 + vorher_21 + vorher_22 + danach_01 + danach_02 + danach_03 + danach_04 + danach_05 + danach_06 + danach_07 + danach_08 + danach_09 + danach_10 + danach_11 + danach_12 + danach_13 + danach_14 + danach_15 + parks + grocery + retail + stations + workplaces + residential    + factor(IdLandkreis) + factor(Meldedatum) + factor(IdBundesland):factor(week)  +0, data=Panel[Panel$Meldedatum>"2020-08-09" & Panel$Meldedatum<"2020-11-09",])
Panel[,74:95] <- 0
Panel$Spiel_pro_Einwohner <- Panel$Spiel/Panel$Einwohner_A3559*100000
for (i in 1:22){
  a <- i
  b <- 73+i
  Panel[,b] <- dplyr::lag(Panel$Spiel_pro_Einwohner, a)
  Panel$lag_Kreis <- dplyr::lag(Panel$IdLandkreis, a)
  Panel[,b][Panel$lag_Kreis!=Panel$IdLandkreis] <- 0
  Panel[,b][is.na(Panel[,b])] <- 0
}
Panel[,97:111] <- 0
for (i in 1:15){
  a <- i
  b <- 96+i
  Panel[,b] <- dplyr::lead(Panel$Spiel_pro_Einwohner, a)
  Panel$lag_Kreis <- dplyr::lead(Panel$IdLandkreis, a)
  Panel[,b][Panel$lag_Kreis!=Panel$IdLandkreis] <- 0
  Panel[,b][is.na(Panel[,b])] <- 0
}
Panel$Faelle_pro_Einwohner_0014 <- Panel$Faelle_0014/Panel$Einwohner_A0014*100000
Panel$Faelle_pro_Einwohner_1534 <- Panel$Faelle_1534/Panel$Einwohner_A1534*100000
Panel$Faelle_pro_Einwohner_3559 <- Panel$Faelle_3559/Panel$Einwohner_A3559*100000
Panel$Faelle_pro_Einwohner_60 <- Panel$Faelle_60/Panel$Einwohner_A60*100000
Panel$vorher_22[is.na(Panel$vorher_22)] <- 0
Panel$danach_15[is.na(Panel$danach_15)] <- 0
for (i in unique(Panel$IdLandkreis)){
  a <- Panel[Panel$IdLandkreis==i,]
  a$vorher_22 <- cumsum(a$vorher_22)
  Panel$vorher_22[Panel$IdLandkreis==i] <- a$vorher_22
}
for (i in unique(Panel$IdLandkreis)){
  a <- Panel[Panel$IdLandkreis==i,]
  a$danach_15 <- rev(cumsum(rev(a$danach_15)))
  Panel$danach_15[Panel$IdLandkreis==i] <- a$danach_15
}
# Binned Regressions
Panel$vorher0103 <- Panel$vorher_01+Panel$vorher_02+Panel$vorher_03
Panel$vorher0406 <- Panel$vorher_04+Panel$vorher_05+Panel$vorher_06
Panel$vorher0709 <- Panel$vorher_07+Panel$vorher_08+Panel$vorher_09
Panel$vorher1012 <- Panel$vorher_10+Panel$vorher_11+Panel$vorher_12
Panel$vorher1315 <- Panel$vorher_13+Panel$vorher_14+Panel$vorher_15
Panel$vorher1618 <- Panel$vorher_16+Panel$vorher_17+Panel$vorher_18
Panel$vorher1921 <- Panel$vorher_19+Panel$vorher_20+Panel$vorher_21
Panel$danach0103 <- Panel$danach_01+Panel$danach_02+Panel$danach_03
Panel$danach0406 <- Panel$danach_04+Panel$danach_05+Panel$danach_06
Panel$danach0709 <- Panel$danach_07+Panel$danach_08+Panel$danach_09
Panel$danach1012 <- Panel$danach_10+Panel$danach_11+Panel$danach_12
Panel$danach1314 <- Panel$danach_13+Panel$danach_14
reg3 <- summary(feols(Faelle_pro_Einwohner_3559 ~ vorher0103 + vorher0406 + vorher0709 + vorher1012 + vorher1315 + vorher1618 + vorher1921 + vorher_22 +
                        danach0103 + danach0406 + danach0709 + danach1012 + danach1314 + danach_15 + parks + grocery + retail + stations + workplaces + residential    | IdLandkreis + Meldedatum + stateweek  +0, Panel[Panel$Meldedatum>"2020-08-09" & Panel$Meldedatum<"2020-11-09",], cluster= ~IdLandkreis))
#reg3 <- lm(Faelle_pro_Einwohner_3559 ~ vorher_01 + vorher_02 + vorher_03 + vorher_04 + vorher_05 + vorher_06 + vorher_07 + vorher_08 + vorher_09 + vorher_10 + vorher_11 + vorher_12 + vorher_13 + vorher_14 + vorher_15 + vorher_16 + vorher_17 + vorher_18 + vorher_19 + vorher_20 + vorher_21 + vorher_22 + danach_01 + danach_02 + danach_03 + danach_04 + danach_05 + danach_06 + danach_07 + danach_08 + danach_09 + danach_10 + danach_11 + danach_12 + danach_13 + danach_14 + danach_15 + parks + grocery + retail + stations + workplaces + residential    + factor(IdLandkreis) + factor(Meldedatum) + factor(IdBundesland):factor(week)  +0, data=Panel[Panel$Meldedatum>"2020-08-09" & Panel$Meldedatum<"2020-11-09",])
Panel[,74:95] <- 0
Panel$Spiel_pro_Einwohner <- Panel$Spiel/Panel$Einwohner_A60*100000
for (i in 1:22){
  a <- i
  b <- 73+i
  Panel[,b] <- dplyr::lag(Panel$Spiel_pro_Einwohner, a)
  Panel$lag_Kreis <- dplyr::lag(Panel$IdLandkreis, a)
  Panel[,b][Panel$lag_Kreis!=Panel$IdLandkreis] <- 0
  Panel[,b][is.na(Panel[,b])] <- 0
}
Panel[,97:111] <- 0
for (i in 1:15){
  a <- i
  b <- 96+i
  Panel[,b] <- dplyr::lead(Panel$Spiel_pro_Einwohner, a)
  Panel$lag_Kreis <- dplyr::lead(Panel$IdLandkreis, a)
  Panel[,b][Panel$lag_Kreis!=Panel$IdLandkreis] <- 0
  Panel[,b][is.na(Panel[,b])] <- 0
}
Panel$Faelle_pro_Einwohner_0014 <- Panel$Faelle_0014/Panel$Einwohner_A0014*100000
Panel$Faelle_pro_Einwohner_1534 <- Panel$Faelle_1534/Panel$Einwohner_A1534*100000
Panel$Faelle_pro_Einwohner_3559 <- Panel$Faelle_3559/Panel$Einwohner_A3559*100000
Panel$Faelle_pro_Einwohner_60 <- Panel$Faelle_60/Panel$Einwohner_A60*100000
Panel$vorher_22[is.na(Panel$vorher_22)] <- 0
Panel$danach_15[is.na(Panel$danach_15)] <- 0
for (i in unique(Panel$IdLandkreis)){
  a <- Panel[Panel$IdLandkreis==i,]
  a$vorher_22 <- cumsum(a$vorher_22)
  Panel$vorher_22[Panel$IdLandkreis==i] <- a$vorher_22
}
for (i in unique(Panel$IdLandkreis)){
  a <- Panel[Panel$IdLandkreis==i,]
  a$danach_15 <- rev(cumsum(rev(a$danach_15)))
  Panel$danach_15[Panel$IdLandkreis==i] <- a$danach_15
}
# Binned Regressions
Panel$vorher0103 <- Panel$vorher_01+Panel$vorher_02+Panel$vorher_03
Panel$vorher0406 <- Panel$vorher_04+Panel$vorher_05+Panel$vorher_06
Panel$vorher0709 <- Panel$vorher_07+Panel$vorher_08+Panel$vorher_09
Panel$vorher1012 <- Panel$vorher_10+Panel$vorher_11+Panel$vorher_12
Panel$vorher1315 <- Panel$vorher_13+Panel$vorher_14+Panel$vorher_15
Panel$vorher1618 <- Panel$vorher_16+Panel$vorher_17+Panel$vorher_18
Panel$vorher1921 <- Panel$vorher_19+Panel$vorher_20+Panel$vorher_21
Panel$danach0103 <- Panel$danach_01+Panel$danach_02+Panel$danach_03
Panel$danach0406 <- Panel$danach_04+Panel$danach_05+Panel$danach_06
Panel$danach0709 <- Panel$danach_07+Panel$danach_08+Panel$danach_09
Panel$danach1012 <- Panel$danach_10+Panel$danach_11+Panel$danach_12
Panel$danach1314 <- Panel$danach_13+Panel$danach_14
reg4 <- summary(feols(Faelle_pro_Einwohner_60 ~ vorher0103 + vorher0406 + vorher0709 + vorher1012 + vorher1315 + vorher1618 + vorher1921 + vorher_22 +
                        danach0103 + danach0406 + danach0709 + danach1012 + danach1314 + danach_15 + parks + grocery + retail + stations + workplaces + residential    | IdLandkreis + Meldedatum + stateweek  +0, Panel[Panel$Meldedatum>"2020-08-09" & Panel$Meldedatum<"2020-11-09",], cluster= ~IdLandkreis))

# Figure A6: Left Top Plot
coefficient <- reg1$coefficients[c(1:7,9:13)]
st_error <- reg1$se[c(1:7,9:13)]*1.96
timing <- c(" [1,3]", " [4,6]", " [7,9]", "[10,12]", "[13,15]","[16,18]", "[19,21]", " [-3,-1]", "  [-6,-4]", "   [-9,-7]", "   [-12,-10]", "    [-14,-13]")
data <- as.data.frame(cbind(coefficient, st_error, timing))
data[13,] <- c(0,0," [0]")
data$coefficient <- as.numeric(data$coefficient)
data$st_error <- as.numeric(data$st_error)
ggplot(data, aes(x=timing)) + geom_ribbon(aes(ymin=coefficient-st_error, ymax=coefficient+st_error), alpha=0.2, fill="blue", group=1) + geom_ribbon(aes(ymin=coefficient-st_error/1.959964*1.64, ymax=coefficient+st_error/1.959964*1.64), alpha=0.35, fill="blue", group=1) + geom_point(aes(y=coefficient), col="navyblue", size=2) + geom_line(aes(y=coefficient), col="navyblue", size=0.5, group=1) + theme_classic() + geom_hline(yintercept=0, linetype="dashed") + geom_vline(xintercept=6, linetype="dashed") + labs(y="Daily Cases per 100,000", x="Days") + ylim(-1,2)

# Figure A6: Left Bottom Plot
coefficient <- reg2$coefficients[c(1:7,9:13)]
st_error <- reg2$se[c(1:7,9:13)]*1.96
timing <- c(" [1,3]", " [4,6]", " [7,9]", "[10,12]", "[13,15]","[16,18]", "[19,21]", " [-3,-1]", "  [-6,-4]", "   [-9,-7]", "   [-12,-10]", "    [-14,-13]")
data <- as.data.frame(cbind(coefficient, st_error, timing))
data[13,] <- c(0,0," [0]")
data$coefficient <- as.numeric(data$coefficient)
data$st_error <- as.numeric(data$st_error)
ggplot(data, aes(x=timing)) + geom_ribbon(aes(ymin=coefficient-st_error, ymax=coefficient+st_error), alpha=0.2, fill="blue", group=1) + geom_ribbon(aes(ymin=coefficient-st_error/1.959964*1.64, ymax=coefficient+st_error/1.959964*1.64), alpha=0.35, fill="blue", group=1) + geom_point(aes(y=coefficient), col="navyblue", size=2) + geom_line(aes(y=coefficient), col="navyblue", size=0.5, group=1) + theme_classic() + geom_hline(yintercept=0, linetype="dashed") + geom_vline(xintercept=6, linetype="dashed") + labs(y="Daily Cases per 100,000", x="Days") + ylim(-1,2)

# Figure A6: Left Top Plot
coefficient <- reg3$coefficients[c(1:7,9:13)]
st_error <- reg3$se[c(1:7,9:13)]*1.96
timing <- c(" [1,3]", " [4,6]", " [7,9]", "[10,12]", "[13,15]","[16,18]", "[19,21]", " [-3,-1]", "  [-6,-4]", "   [-9,-7]", "   [-12,-10]", "    [-14,-13]")
data <- as.data.frame(cbind(coefficient, st_error, timing))
data[13,] <- c(0,0," [0]")
data$coefficient <- as.numeric(data$coefficient)
data$st_error <- as.numeric(data$st_error)
ggplot(data, aes(x=timing)) + geom_ribbon(aes(ymin=coefficient-st_error, ymax=coefficient+st_error), alpha=0.2, fill="blue", group=1) + geom_ribbon(aes(ymin=coefficient-st_error/1.959964*1.64, ymax=coefficient+st_error/1.959964*1.64), alpha=0.35, fill="blue", group=1) + geom_point(aes(y=coefficient), col="navyblue", size=2) + geom_line(aes(y=coefficient), col="navyblue", size=0.5, group=1) + theme_classic() + geom_hline(yintercept=0, linetype="dashed") + geom_vline(xintercept=6, linetype="dashed") + labs(y="Daily Cases per 100,000", x="Days") + ylim(-1,2)

# Figure A6: Right Top Plot
coefficient <- reg4$coefficients[c(1:7,9:13)]
st_error <- reg4$se[c(1:7,9:13)]*1.96
timing <- c(" [1,3]", " [4,6]", " [7,9]", "[10,12]", "[13,15]","[16,18]", "[19,21]", " [-3,-1]", "  [-6,-4]", "   [-9,-7]", "   [-12,-10]", "    [-14,-13]")
data <- as.data.frame(cbind(coefficient, st_error, timing))
data[13,] <- c(0,0," [0]")
data$coefficient <- as.numeric(data$coefficient)
data$st_error <- as.numeric(data$st_error)
ggplot(data, aes(x=timing)) + geom_ribbon(aes(ymin=coefficient-st_error, ymax=coefficient+st_error), alpha=0.2, fill="blue", group=1) + geom_ribbon(aes(ymin=coefficient-st_error/1.959964*1.64, ymax=coefficient+st_error/1.959964*1.64), alpha=0.35, fill="blue", group=1) + geom_point(aes(y=coefficient), col="navyblue", size=2) + geom_line(aes(y=coefficient), col="navyblue", size=0.5, group=1) + theme_classic() + geom_hline(yintercept=0, linetype="dashed") + geom_vline(xintercept=6, linetype="dashed") + labs(y="Daily Cases per 100,000", x="Days") + ylim(-1,2)




Panel$Spiel_pro_Einwohner <- Panel$Zuschauer/Panel$Einwohner_A0014*100000
#Panel$Spiel_pro_Einwohner <- scale(Panel$Spiel_pro_Einwohner)
for (i in 1:22){
  a <- i
  b <- 73+i
  Panel[,b] <- dplyr::lag(Panel$Spiel_pro_Einwohner, a)
  Panel$lag_Kreis <- dplyr::lag(Panel$IdLandkreis, a)
  Panel[,b][Panel$lag_Kreis!=Panel$IdLandkreis] <- 0
  Panel[,b][is.na(Panel[,b])] <- 0
}
Panel[,97:111] <- 0
for (i in 1:15){
  a <- i
  b <- 96+i
  Panel[,b] <- dplyr::lead(Panel$Spiel_pro_Einwohner, a)
  Panel$lag_Kreis <- dplyr::lead(Panel$IdLandkreis, a)
  Panel[,b][Panel$lag_Kreis!=Panel$IdLandkreis] <- 0
  Panel[,b][is.na(Panel[,b])] <- 0
}
Panel$Faelle_pro_Einwohner_0014 <- Panel$Faelle_0014/Panel$Einwohner_A0014*100000
Panel$Faelle_pro_Einwohner_1534 <- Panel$Faelle_1534/Panel$Einwohner_A1534*100000
Panel$Faelle_pro_Einwohner_3559 <- Panel$Faelle_3559/Panel$Einwohner_A3559*100000
Panel$Faelle_pro_Einwohner_60 <- Panel$Faelle_60/Panel$Einwohner_A60*100000
Panel$vorher_22[is.na(Panel$vorher_22)] <- 0
Panel$danach_15[is.na(Panel$danach_15)] <- 0
for (i in unique(Panel$IdLandkreis)){
  a <- Panel[Panel$IdLandkreis==i,]
  a$vorher_22 <- cumsum(a$vorher_22)
  Panel$vorher_22[Panel$IdLandkreis==i] <- a$vorher_22
}
for (i in unique(Panel$IdLandkreis)){
  a <- Panel[Panel$IdLandkreis==i,]
  a$danach_15 <- rev(cumsum(rev(a$danach_15)))
  Panel$danach_15[Panel$IdLandkreis==i] <- a$danach_15
}
# Binned Regressions
Panel$vorher0103 <- Panel$vorher_01+Panel$vorher_02+Panel$vorher_03
Panel$vorher0406 <- Panel$vorher_04+Panel$vorher_05+Panel$vorher_06
Panel$vorher0709 <- Panel$vorher_07+Panel$vorher_08+Panel$vorher_09
Panel$vorher1012 <- Panel$vorher_10+Panel$vorher_11+Panel$vorher_12
Panel$vorher1315 <- Panel$vorher_13+Panel$vorher_14+Panel$vorher_15
Panel$vorher1618 <- Panel$vorher_16+Panel$vorher_17+Panel$vorher_18
Panel$vorher1921 <- Panel$vorher_19+Panel$vorher_20+Panel$vorher_21
Panel$danach0103 <- Panel$danach_01+Panel$danach_02+Panel$danach_03
Panel$danach0406 <- Panel$danach_04+Panel$danach_05+Panel$danach_06
Panel$danach0709 <- Panel$danach_07+Panel$danach_08+Panel$danach_09
Panel$danach1012 <- Panel$danach_10+Panel$danach_11+Panel$danach_12
Panel$danach1314 <- Panel$danach_13+Panel$danach_14
reg1 <- summary(feols(Faelle_pro_Einwohner_0014 ~ vorher0103 + vorher0406 + vorher0709 + vorher1012 + vorher1315 + vorher1618 + vorher1921 + vorher_22 +
                        danach0103 + danach0406 + danach0709 + danach1012 + danach1314 + danach_15 + parks + grocery + retail + stations + workplaces + residential    | IdLandkreis + Meldedatum + stateweek  +0, Panel[Panel$Meldedatum>"2020-08-09" & Panel$Meldedatum<"2020-11-09",], cluster= ~IdLandkreis))


Panel[,74:95] <- 0
Panel$Spiel_pro_Einwohner <- Panel$Zuschauer/Panel$Einwohner_A1534*100000
#Panel$Spiel_pro_Einwohner <- scale(Panel$Spiel_pro_Einwohner)
for (i in 1:22){
  a <- i
  b <- 73+i
  Panel[,b] <- dplyr::lag(Panel$Spiel_pro_Einwohner, a)
  Panel$lag_Kreis <- dplyr::lag(Panel$IdLandkreis, a)
  Panel[,b][Panel$lag_Kreis!=Panel$IdLandkreis] <- 0
  Panel[,b][is.na(Panel[,b])] <- 0
}
Panel[,97:111] <- 0
for (i in 1:15){
  a <- i
  b <- 96+i
  Panel[,b] <- dplyr::lead(Panel$Spiel_pro_Einwohner, a)
  Panel$lag_Kreis <- dplyr::lead(Panel$IdLandkreis, a)
  Panel[,b][Panel$lag_Kreis!=Panel$IdLandkreis] <- 0
  Panel[,b][is.na(Panel[,b])] <- 0
}
Panel$Faelle_pro_Einwohner_0014 <- Panel$Faelle_0014/Panel$Einwohner_A0014*100000
Panel$Faelle_pro_Einwohner_1534 <- Panel$Faelle_1534/Panel$Einwohner_A1534*100000
Panel$Faelle_pro_Einwohner_3559 <- Panel$Faelle_3559/Panel$Einwohner_A3559*100000
Panel$Faelle_pro_Einwohner_60 <- Panel$Faelle_60/Panel$Einwohner_A60*100000
Panel$vorher_22[is.na(Panel$vorher_22)] <- 0
Panel$danach_15[is.na(Panel$danach_15)] <- 0
for (i in unique(Panel$IdLandkreis)){
  a <- Panel[Panel$IdLandkreis==i,]
  a$vorher_22 <- cumsum(a$vorher_22)
  Panel$vorher_22[Panel$IdLandkreis==i] <- a$vorher_22
}
for (i in unique(Panel$IdLandkreis)){
  a <- Panel[Panel$IdLandkreis==i,]
  a$danach_15 <- rev(cumsum(rev(a$danach_15)))
  Panel$danach_15[Panel$IdLandkreis==i] <- a$danach_15
}
# Binned Regressions
Panel$vorher0103 <- Panel$vorher_01+Panel$vorher_02+Panel$vorher_03
Panel$vorher0406 <- Panel$vorher_04+Panel$vorher_05+Panel$vorher_06
Panel$vorher0709 <- Panel$vorher_07+Panel$vorher_08+Panel$vorher_09
Panel$vorher1012 <- Panel$vorher_10+Panel$vorher_11+Panel$vorher_12
Panel$vorher1315 <- Panel$vorher_13+Panel$vorher_14+Panel$vorher_15
Panel$vorher1618 <- Panel$vorher_16+Panel$vorher_17+Panel$vorher_18
Panel$vorher1921 <- Panel$vorher_19+Panel$vorher_20+Panel$vorher_21
Panel$danach0103 <- Panel$danach_01+Panel$danach_02+Panel$danach_03
Panel$danach0406 <- Panel$danach_04+Panel$danach_05+Panel$danach_06
Panel$danach0709 <- Panel$danach_07+Panel$danach_08+Panel$danach_09
Panel$danach1012 <- Panel$danach_10+Panel$danach_11+Panel$danach_12
Panel$danach1314 <- Panel$danach_13+Panel$danach_14
reg2 <- summary(feols(Faelle_pro_Einwohner_1534 ~ vorher0103 + vorher0406 + vorher0709 + vorher1012 + vorher1315 + vorher1618 + vorher1921 + vorher_22 +
                        danach0103 + danach0406 + danach0709 + danach1012 + danach1314 + danach_15 + parks + grocery + retail + stations + workplaces + residential    | IdLandkreis + Meldedatum + stateweek  +0, Panel[Panel$Meldedatum>"2020-08-09" & Panel$Meldedatum<"2020-11-09",], cluster= ~IdLandkreis))


Panel[,74:95] <- 0
Panel$Spiel_pro_Einwohner <- Panel$Zuschauer/Panel$Einwohner_A3559*100000
#Panel$Spiel_pro_Einwohner <- scale(Panel$Spiel_pro_Einwohner)
for (i in 1:22){
  a <- i
  b <- 73+i
  Panel[,b] <- dplyr::lag(Panel$Spiel_pro_Einwohner, a)
  Panel$lag_Kreis <- dplyr::lag(Panel$IdLandkreis, a)
  Panel[,b][Panel$lag_Kreis!=Panel$IdLandkreis] <- 0
  Panel[,b][is.na(Panel[,b])] <- 0
}
Panel[,97:111] <- 0
for (i in 1:15){
  a <- i
  b <- 96+i
  Panel[,b] <- dplyr::lead(Panel$Spiel_pro_Einwohner, a)
  Panel$lag_Kreis <- dplyr::lead(Panel$IdLandkreis, a)
  Panel[,b][Panel$lag_Kreis!=Panel$IdLandkreis] <- 0
  Panel[,b][is.na(Panel[,b])] <- 0
}
Panel$Faelle_pro_Einwohner_0014 <- Panel$Faelle_0014/Panel$Einwohner_A0014*100000
Panel$Faelle_pro_Einwohner_1534 <- Panel$Faelle_1534/Panel$Einwohner_A1534*100000
Panel$Faelle_pro_Einwohner_3559 <- Panel$Faelle_3559/Panel$Einwohner_A3559*100000
Panel$Faelle_pro_Einwohner_60 <- Panel$Faelle_60/Panel$Einwohner_A60*100000
Panel$vorher_22[is.na(Panel$vorher_22)] <- 0
Panel$danach_15[is.na(Panel$danach_15)] <- 0
for (i in unique(Panel$IdLandkreis)){
  a <- Panel[Panel$IdLandkreis==i,]
  a$vorher_22 <- cumsum(a$vorher_22)
  Panel$vorher_22[Panel$IdLandkreis==i] <- a$vorher_22
}
for (i in unique(Panel$IdLandkreis)){
  a <- Panel[Panel$IdLandkreis==i,]
  a$danach_15 <- rev(cumsum(rev(a$danach_15)))
  Panel$danach_15[Panel$IdLandkreis==i] <- a$danach_15
}
# Binned Regressions
Panel$vorher0103 <- Panel$vorher_01+Panel$vorher_02+Panel$vorher_03
Panel$vorher0406 <- Panel$vorher_04+Panel$vorher_05+Panel$vorher_06
Panel$vorher0709 <- Panel$vorher_07+Panel$vorher_08+Panel$vorher_09
Panel$vorher1012 <- Panel$vorher_10+Panel$vorher_11+Panel$vorher_12
Panel$vorher1315 <- Panel$vorher_13+Panel$vorher_14+Panel$vorher_15
Panel$vorher1618 <- Panel$vorher_16+Panel$vorher_17+Panel$vorher_18
Panel$vorher1921 <- Panel$vorher_19+Panel$vorher_20+Panel$vorher_21
Panel$danach0103 <- Panel$danach_01+Panel$danach_02+Panel$danach_03
Panel$danach0406 <- Panel$danach_04+Panel$danach_05+Panel$danach_06
Panel$danach0709 <- Panel$danach_07+Panel$danach_08+Panel$danach_09
Panel$danach1012 <- Panel$danach_10+Panel$danach_11+Panel$danach_12
Panel$danach1314 <- Panel$danach_13+Panel$danach_14
reg3 <- summary(feols(Faelle_pro_Einwohner_3559 ~ vorher0103 + vorher0406 + vorher0709 + vorher1012 + vorher1315 + vorher1618 + vorher1921 + vorher_22 +
                        danach0103 + danach0406 + danach0709 + danach1012 + danach1314 + danach_15 + parks + grocery + retail + stations + workplaces + residential    | IdLandkreis + Meldedatum + stateweek  +0, Panel[Panel$Meldedatum>"2020-08-09" & Panel$Meldedatum<"2020-11-09",], cluster= ~IdLandkreis))

Panel[,74:95] <- 0
Panel$Spiel_pro_Einwohner <- Panel$Zuschauer/Panel$Einwohner_A60*100000
#Panel$Spiel_pro_Einwohner <- scale(Panel$Spiel_pro_Einwohner)
for (i in 1:22){
  a <- i
  b <- 73+i
  Panel[,b] <- dplyr::lag(Panel$Spiel_pro_Einwohner, a)
  Panel$lag_Kreis <- dplyr::lag(Panel$IdLandkreis, a)
  Panel[,b][Panel$lag_Kreis!=Panel$IdLandkreis] <- 0
  Panel[,b][is.na(Panel[,b])] <- 0
}
Panel[,97:111] <- 0
for (i in 1:15){
  a <- i
  b <- 96+i
  Panel[,b] <- dplyr::lead(Panel$Spiel_pro_Einwohner, a)
  Panel$lag_Kreis <- dplyr::lead(Panel$IdLandkreis, a)
  Panel[,b][Panel$lag_Kreis!=Panel$IdLandkreis] <- 0
  Panel[,b][is.na(Panel[,b])] <- 0
}
Panel$Faelle_pro_Einwohner_0014 <- Panel$Faelle_0014/Panel$Einwohner_A0014*100000
Panel$Faelle_pro_Einwohner_1534 <- Panel$Faelle_1534/Panel$Einwohner_A1534*100000
Panel$Faelle_pro_Einwohner_3559 <- Panel$Faelle_3559/Panel$Einwohner_A3559*100000
Panel$Faelle_pro_Einwohner_60 <- Panel$Faelle_60/Panel$Einwohner_A60*100000
Panel$vorher_22[is.na(Panel$vorher_22)] <- 0
Panel$danach_15[is.na(Panel$danach_15)] <- 0
for (i in unique(Panel$IdLandkreis)){
  a <- Panel[Panel$IdLandkreis==i,]
  a$vorher_22 <- cumsum(a$vorher_22)
  Panel$vorher_22[Panel$IdLandkreis==i] <- a$vorher_22
}
for (i in unique(Panel$IdLandkreis)){
  a <- Panel[Panel$IdLandkreis==i,]
  a$danach_15 <- rev(cumsum(rev(a$danach_15)))
  Panel$danach_15[Panel$IdLandkreis==i] <- a$danach_15
}
# Binned Regressions
Panel$vorher0103 <- Panel$vorher_01+Panel$vorher_02+Panel$vorher_03
Panel$vorher0406 <- Panel$vorher_04+Panel$vorher_05+Panel$vorher_06
Panel$vorher0709 <- Panel$vorher_07+Panel$vorher_08+Panel$vorher_09
Panel$vorher1012 <- Panel$vorher_10+Panel$vorher_11+Panel$vorher_12
Panel$vorher1315 <- Panel$vorher_13+Panel$vorher_14+Panel$vorher_15
Panel$vorher1618 <- Panel$vorher_16+Panel$vorher_17+Panel$vorher_18
Panel$vorher1921 <- Panel$vorher_19+Panel$vorher_20+Panel$vorher_21
Panel$danach0103 <- Panel$danach_01+Panel$danach_02+Panel$danach_03
Panel$danach0406 <- Panel$danach_04+Panel$danach_05+Panel$danach_06
Panel$danach0709 <- Panel$danach_07+Panel$danach_08+Panel$danach_09
Panel$danach1012 <- Panel$danach_10+Panel$danach_11+Panel$danach_12
Panel$danach1314 <- Panel$danach_13+Panel$danach_14
reg4 <- summary(feols(Faelle_pro_Einwohner_60 ~ vorher0103 + vorher0406 + vorher0709 + vorher1012 + vorher1315 + vorher1618 + vorher1921 + vorher_22 +
                        danach0103 + danach0406 + danach0709 + danach1012 + danach1314 + danach_15 + parks + grocery + retail + stations + workplaces + residential    | IdLandkreis + Meldedatum + stateweek  +0, Panel[Panel$Meldedatum>"2020-08-09" & Panel$Meldedatum<"2020-11-09",], cluster= ~IdLandkreis))

# Figure A7: Left Top Plot
coefficient <- reg1$coefficients[c(1:7,9:13)]
st_error <- reg1$se[c(1:7,9:13)]*1.96
timing <- c(" [1,3]", " [4,6]", " [7,9]", "[10,12]", "[13,15]","[16,18]", "[19,21]", " [-3,-1]", "  [-6,-4]", "   [-9,-7]", "   [-12,-10]", "    [-14,-13]")
data <- as.data.frame(cbind(coefficient, st_error, timing))
data[13,] <- c(0,0," [0]")
data$coefficient <- as.numeric(data$coefficient)
data$st_error <- as.numeric(data$st_error)
ggplot(data, aes(x=timing)) + geom_ribbon(aes(ymin=coefficient-st_error, ymax=coefficient+st_error), alpha=0.2, fill="blue", group=1) + geom_ribbon(aes(ymin=coefficient-st_error/1.959964*1.64, ymax=coefficient+st_error/1.959964*1.64), alpha=0.35, fill="blue", group=1) + geom_point(aes(y=coefficient), col="navyblue", size=2) + geom_line(aes(y=coefficient), col="navyblue", size=0.5, group=1) + theme_classic() + geom_hline(yintercept=0, linetype="dashed") + geom_vline(xintercept=6, linetype="dashed") + labs(y="Daily Cases per 100,000", x="Days") + ylim(-0.0005,0.001)

# Figure A7: Right Top Plot
coefficient <- reg2$coefficients[c(1:7,9:13)]
st_error <- reg2$se[c(1:7,9:13)]*1.96
timing <- c(" [1,3]", " [4,6]", " [7,9]", "[10,12]", "[13,15]","[16,18]", "[19,21]", " [-3,-1]", "  [-6,-4]", "   [-9,-7]", "   [-12,-10]", "    [-14,-13]")
data <- as.data.frame(cbind(coefficient, st_error, timing))
data[13,] <- c(0,0," [0]")
data$coefficient <- as.numeric(data$coefficient)
data$st_error <- as.numeric(data$st_error)
ggplot(data, aes(x=timing)) + geom_ribbon(aes(ymin=coefficient-st_error, ymax=coefficient+st_error), alpha=0.2, fill="blue", group=1) + geom_ribbon(aes(ymin=coefficient-st_error/1.959964*1.64, ymax=coefficient+st_error/1.959964*1.64), alpha=0.35, fill="blue", group=1) + geom_point(aes(y=coefficient), col="navyblue", size=2) + geom_line(aes(y=coefficient), col="navyblue", size=0.5, group=1) + theme_classic() + geom_hline(yintercept=0, linetype="dashed") + geom_vline(xintercept=6, linetype="dashed") + labs(y="Daily Cases per 100,000", x="Days") + ylim(-0.0005,0.001)

# Figure A7: Left Bottom Plot
coefficient <- reg3$coefficients[c(1:7,9:13)]
st_error <- reg3$se[c(1:7,9:13)]*1.96
timing <- c(" [1,3]", " [4,6]", " [7,9]", "[10,12]", "[13,15]","[16,18]", "[19,21]", " [-3,-1]", "  [-6,-4]", "   [-9,-7]", "   [-12,-10]", "    [-14,-13]")
data <- as.data.frame(cbind(coefficient, st_error, timing))
data[13,] <- c(0,0," [0]")
data$coefficient <- as.numeric(data$coefficient)
data$st_error <- as.numeric(data$st_error)
ggplot(data, aes(x=timing)) + geom_ribbon(aes(ymin=coefficient-st_error, ymax=coefficient+st_error), alpha=0.2, fill="blue", group=1) + geom_ribbon(aes(ymin=coefficient-st_error/1.959964*1.64, ymax=coefficient+st_error/1.959964*1.64), alpha=0.35, fill="blue", group=1) + geom_point(aes(y=coefficient), col="navyblue", size=2) + geom_line(aes(y=coefficient), col="navyblue", size=0.5, group=1) + theme_classic() + geom_hline(yintercept=0, linetype="dashed") + geom_vline(xintercept=6, linetype="dashed") + labs(y="Daily Cases per 100,000", x="Days") + ylim(-0.0005,0.001)

# Figure A7: Right Bottom Plot
coefficient <- reg4$coefficients[c(1:7,9:13)]
st_error <- reg4$se[c(1:7,9:13)]*1.96
timing <- c(" [1,3]", " [4,6]", " [7,9]", "[10,12]", "[13,15]","[16,18]", "[19,21]", " [-3,-1]", "  [-6,-4]", "   [-9,-7]", "   [-12,-10]", "    [-14,-13]")
data <- as.data.frame(cbind(coefficient, st_error, timing))
data[13,] <- c(0,0," [0]")
data$coefficient <- as.numeric(data$coefficient)
data$st_error <- as.numeric(data$st_error)
ggplot(data, aes(x=timing)) + geom_ribbon(aes(ymin=coefficient-st_error, ymax=coefficient+st_error), alpha=0.2, fill="blue", group=1) + geom_ribbon(aes(ymin=coefficient-st_error/1.959964*1.64, ymax=coefficient+st_error/1.959964*1.64), alpha=0.35, fill="blue", group=1) + geom_point(aes(y=coefficient), col="navyblue", size=2) + geom_line(aes(y=coefficient), col="navyblue", size=0.5, group=1) + theme_classic() + geom_hline(yintercept=0, linetype="dashed") + geom_vline(xintercept=6, linetype="dashed") + labs(y="Daily Cases per 100,000", x="Days") + ylim(-0.0005,0.001)